
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xf3,\x00\x00\x00\x97\x00d\x00d\x01l\x00m\x01Z\x01\x01\x00\x02\x00e\x01e\x02e\x03d\x02\xa6\x03\x00\x00\xab\x03\x00\x00\x00\x00\x00\x00\x00\x00'
        b'\x01\x00d\x03S\x00)\x04\xe9\x01\x00\x00\x00)\x01\xda\x0b__pyarmor__s\xeb[\x00\x00PY004022\x00\x03\x0b\x00\xa7\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00'
        b'\x00\xab[\x00\x002\t\x05\x00\xc1\xa1\xf4:\x17\x06\xe1\x17?*\x12\n\xbe\xb2\x92J\x00\x00\x00\x00\x00\x00\x00\x00Ox\x18\xdd\x1d?\x11J\x9e\x01f+\x9b\xc4\xabn\x80<\x9c:\xd4N\xb7\xbaXd\x8d\xdb!\xf0\xf6'
        b't\x8d\x12r\xc6r\r\xb1$;\xd4\xa7\xd3\x9bq\xc2\xf3\xcf\xdc\x02\x00]\xab\xb5w\xe5\x89D|a\xc6\xa8\xec\xb6\x9b\r\xb0\xca9%\xa20i\x9e\x00XR\x96\xfb\x1a\x1cV\xc3\xbcY\xcfh|\x96\x94\xef\x9a\xa3l'
        b'\x99\xb9/9{\xb3D9\xa8\x95B\x11\x03p\xbb\xef\x8cV\x07\xa4X.\xd6\xae|\x1a\x12\x99\xe0\x80\xc0\xbb\x8eK\x05\xd7)\xff,\xc4G\xc9\x0e\x80F\xe1-c\xfd=.c\x90\xc4\x1f\xfeD\xda\xe4\xa3\xdafC@'
        b"\x8e\x15\xc76\rS\xbb@y\xc5\x94\x9a\xaf\x9b\xed\xba.\xe1\xe4\x19\x1f;\xdb\xf4\x06v\x00y\x19Ao#\x05\xf2\xe9\xe6\x9du\xc5\xc9\x8b.\\a\x00\x8f\xd6w\x8eY/'\xb7\xb0\x02\x90L\xddJ\x01\x12\xfcZ\xa7"
        b'\x82a"^\xed\x0c\xfb?\xa7C\xde\xbf\xc5"\xb2\x1b\x1c\xce\x18d\xf5\xc7\x08,\xe6fX>\xb2cP\xa3\x80\xde8\x03\xf42T\x1e\xb2\x9c\xcb\x0e\x06\x0e2\x0b\xb1\xfbAp\xd1w\xd0\x8d\x01\x18\x10\xbb\x173\xa8\\'
        b"P\xd7\xddI\xb3\xe5\x1a}P3$\x07\x1d&\x8c\x9a\xb4\to`\xd30\xc6\x96\xecH\xdb?\x8a\xa8\x17;\xdc;\x1f\xca\xba\xea5_\xb8\x11WA'\x9c\xd3#i\xb8\x97\x029\xa3\x8e#0\xff\x05u8\x16\x9b\x8d"
        b">\xfd\x8a\x87~\xf5.\xe8C#\x01\xf2}h\xb7*4z\xa2g\x1c\xd6X\xe7<\x89\xa9OD\x06\x8d\xb5\xe7E\rm\xed\xab\x8f\xdd4K\x8a\x7fU';\xea\xb6Sl`\x89\x9f\x9d\xc4[#c5T=Y\x0e"
        b'\x93<\x13:O~\xff\xcc?\x1cY\xbd\x9cZ\xeb\xf73\xbd\xbd$8\x13N\xf0V\x84\x00\x81Z\xd2\xbcB\xf1+C\xd2\x11f\xc7/=\x0e)\xe5d\x9a\xb6`\x11\xbf\xd2\x83\xfb\x94\xe9\x89\x8dJ2\xe0.\xa8\x1d\xcf'
        b')\x9e\x9fb\xecd\x0e:\xca\xa5FK\xe6\xb1sX\x90\xdc\xfd\xcdt\xbc\x1d\xba\xb1T\x17\xf8\x8a\xe2 W{$U6\xcch\x07\x06\x88\xf4\x03\xd3g\x08\xbb\xff\x94\x18J\x12\xc7\xbb\xb25\xd4\x0c\xf5{p\xc6\x9f\x16'
        b'\x9f\xcc\x07\xdad\x83OE\xf2\xaeNl\xd4C\xa2\xe6\x80x\xaca^\xcc\xd8\xfa\xe3rd\x97C\x18]\xcc.\xa0\x9f>\x83\x95X\xde\xb8<\xfa*\x01\r8\xd3\xf5\xec\x19\xe8k\x98\x02\x838\xaf\xa6\xdfD\x83\x96\x90'
        b":?.At'\x19+>\x93\xf16\xd4GM\x81C.\t\xfc~\xff\xef\xd1\x92d\x9ev\x1a0\xf4{k{_\x02i7\x8e\xacb0\x8b\x02I\xf9\x87$\x82]0\x83\xcf\x96\xcc\nZ\xe2\x86\x8a\xd4\xc1\xbf\xaf"
        b')\t\x9a\xc4\xf2)9\x98\xde\xc4\xdfE\xc6\x9e\xfa\x8c\xc8t\x1a\xc1\x8ft_M\x19\xc1\x046"\x13\xa3E\xaf\xaf\r+\xca\xaf\x95\x82\xab\x1ah\x02=\xef\xf6\xae\x08\xbd=\xe6\t\xa5\xbdQ/\xa0\xa1m\x10?\x90\xbd'
        b'\x85\xce\xe7\n\x8b\x9b\xf2\xbc\x1d2&\xc8\x93\xaf\x9d\x82\xafj\xf2\x98t\x1f\x91\x88\x9dI\xad~\xe9|\xb2\x18\xa9\xe2\xdf\xd7\n\x00\x92\x9bmV\xb3=\xe0\xc0Ku4\xa6O\xbb\xcd\xaf\xa3)\xbai\xcex\xa0\x9eI '
        b'\xb2q0\xcc?\x01\x15<\xb9\x83E~"\xa5\xc6\x82a\x81\xb3\xeda\x95Uq\x19\x9b\x98\xc5\x1dW\xf9\xec\xdf\xe5\x1e,\xc7\xd2?\x1c\x1a!\xd3D\xca\xddH\xf9\xe1\t\xad|"\xbfT\xca\xdb\xc2\xb0\x8b\xbbj3\xa8'
        b'\xea\x81\xaf\xd94\x07\xd6q.\xe2\xe86\xaa\x86\xda\x93i\x8aE\xd8{\xc5\x8c\xe0\x8f\xa4\x0f*h\x93\x97\x97\x9cZH\xf5\xffY\xcc\xc4qGS\xeeC\n\xc6\xb6\x99)s\x18U\xca\xc5\xa9] \x9d\xd1\xe9|iY'
        b'\xd2\xbe\xf9d\x85\x134\x9co z\x19\xb7V\x10\xdb\x1a\x05wv\xb7\x15\x08\xc9\x02\xad\xc4\x1f\x8d\x0f\xd7\x16*\x87,s\xea\x85g\xee\xa4\xa1\x9f\x86U<M\xb3R\x7f\xc5\xba\x8f\xe9\'\xb9p\x9aR0"Pbz'
        b"wf\x16\xd2\x93G\xb0\xf6\xe2D}\xd3\xa1\xd9G\xc9\x98\xa7m\xe2\xff\xd7\xa4\xceUJV\x83\xed\xc72\xb3\xe1\x83F'\x15\xac\xa7o\xc0\xdd\xa3G\x90\x10*\xd9\xa8c8\xa7>\xad\xcf\xae2\xa8\xfd\xa0\x91\n\xc7\xe4"
        b"M\x05\xbe\x1eZ\x8b\xf2-U\nN\x8e\xda\xaf\x0c\x0b\x85\xed\xdc\x96~\xca\xf8\xbc}9E=%\xe1\x03t'\xd6\xa1\xed\xaeR\x945\x0e\xa7Z\x7f\xe4\xafm\x8f'#-J\x16~i\xcd\xf8r\xb1n\xd1\xdf\xf4\x84"
        b"*\x1f\x15c\xa0\x05\x9ep\xe5\x04\xf6**?<\xf1\xc5\xe9.Z\xb6p\x8c0'\xd4\x05!\xeb6\x99\x0eP\xa0\xe1|M\xf3;b\x03\x16\xf1\n\x8d\x82\x9e\xf4\x0e\x03\xa5QKlSp\xf6\x9f\xc1\xc6\x94\x94\xa1@"
        b'w\x8do\xa4\x97T\xc1\x8ca\xf9tz\xda4<\xf2\xdb\x1b:Q\xf2|\xb4\xeb\xd3]\x14p\x93{\x14\xa3_e\x11a\xe4\xc4h\xe2\x96\xbc\x15x\xc8]\xc6/\xc7\x04/\x8e\xa3\xebs\x9d\xa1\x0b\x02jT\x93\xe8\x1f'
        b'H=\xb8\xde\x17\xa4\xc3\x1d\t\xe9)G\n\x08j\xd8\xda^J:U\x10\xb8,\x08\x17c\x97D~\x0c"e+\x90\xdfF$\'\xff1\xd3\xbd\xa2\xdd\xf5>\xdb\x8e\xa0\xc8y\xc4\x96\x9f{\xca\xff\xdc\xa8%-@\xe0'
        b'\xe6\x8b\x9dL\x85\xa3\xfd\xde!\xe2S\xd2\xaa\xea8\xa3u\x8cQ\xab+G\xe4o\x8f\x81\xedBh\xf3J\x8b\xae\xf4\x03\xf3\x9b\x06\x93\xb0\x99\xbdM\x9d\xd3\x9f0\x9f\x1eeN\xcfK\xb92\x1d-\x18\xa4c\xbbH\xc87'
        b'\xe0\x8a\x8eU\xeb\x7f"CH\xb5A\x80\x87\x12\x13k\xeaE\xe9\xb0Z_\xae\xd4{\x97\x1c\xb9\x1a\x06\x03\xbf\xb6&\xfa\x9b\xd0R\x05\xeam\xfe3Q\xf9z\x9d@%n52m\x11\x10\x8f=[\x15/\xa7oJ\x9e'
        b"\xbc>\x06Y\xc7f\x9f,\xfa\x16\xa0B\xbb\xd0\xaa=\xa9\xd7T'\x9d\x00{X%\xe0\xa0`\xe5\x1b\xa6o+\xd9\xc8\x1e\xc0\xfanzb\xe2\x93\xd4\xae\xe3\xffg\xfd\x94\xdb\xb8\x11\xc9\x89\x1b\x11c\x9dQd\x9e\xeb\xc6"
        b'*\x87\xc6\xc3s{\xd3\x9d\xc7\xe0fb\\K\xe5\xcb5a2\xd8\x01{\xa7\xe4\xec\xe3$\xb5V\xc9\xc2\x00;H\xf8\xfc\xfb~@\xee\xbdk\xd4q\x996\xd1\x9bl\xd2\xf0y\xd0\xfb<\xfe\xe0n\x8fxk\xb0\xc2#'
        b'\x87+\x99\xac\xa9O\xcdS\xab\xc5y\xcd\xa3\xea\x1bSoSs(?]>\x04\xe4\xc0\rs=\xd0\xf3\xb8N\xee)\xfb\x92\x14\xb8\x1cR\t\xc8\x06\xb37\xb0Z\x0f}\x17\xd0\x1dQ\xc4^\xaefs\xcd_\x0c-N'
        b'\xec\x88\xba\xaaA\xfd\x89\x97\x8d\xa7C\x8a\xb1\xc8\xad\x88\xed\x87`CBN2R\xa38\xdb\xbdW?\xb4\x01\x02\x14\xc8\x88O\x9b\xa1~\xda1\xaej\xe0\xc2\x03:b\x13\xb2"\xc1f[\xf0]N&\x91,\xe8q\x10'
        b'\x9dh\xb48\xd4\x16;\x1e\xf7\xac\xf6F\xb3\xfe\x99\xcf\x85\x05E\x87\xb1\xf6X\xbe\x89\xdc`\xf5\xd6\xd2\x90B\x9a\x94t\x17yMS\xe1\x1a\x91n\x87W\xf2\x9d\x99\xe5\xf2\xe7\xb9\xa4<\x83r"$f_$\xc5qp'
        b'3\xe6\x97\'\x80\xea\x1fR\x12e2\xde\xd3(n~\x85G9\xd8\xde"=\x06_\xd5\x0e\xf9\xa4\x8f\x83\xe0\xac\xe9\xd1o\x93\xcb\x9e\x84I\x8bv\xb9yuF\xb4\xfa\xec\xf7MY\x92\x1d\x9b\xa3\xa5Wy\xd9XMH'
        b'\x13\xa6\xaa\xb7\x14\x98y\xef:\xdd\xb6\xba\xc0AV\xcazZ\xfd\\\xf6\t?\xe2#\x0e\xda\x02]\xd6\xba\xbf\x01%\x16\xa1\xc0\xad\n\x08\xa7\xe1\xa0\\\xc4\xd6Z\xb6\xb1yg\xa9M\xe1A\x8b\xe2H\x96jE\x01\xd0\xdb'
        b')\xc4\xec\x86s\xb5\xf2\x1d\xb9\xecb\xcb%\x91\xf3Rd\xa5\xa9>\xdbG\x13b\xd05h\xb7\xad\xbf\xa4E\x02\xe2\xaf4\xee\xe0C\x8e\xf6!\xff\x96\xa0\xfc\xef\x8aX\xe2\x82\x833\x1c\xdc\x0c\x1d\xfb]\x8e\x06\xc1Q\xe9'
        b"\xc2\x19\xac\t\xe9\xfb'W\xfc\xe6.y\tS+ 3s\x0c\xb8 \\tU\x91\xbe!\xa5\xd0\xb8\x9c#l\x87\x15T3o@\xe1~\xefx\x80\x00%\xb9n\xc7\xf3VJ\xc2\x9e\xc8m7Pg\xbepj\x02\x05"
        b'>"\xe61\x07[H\x875\xa0\xd3\xcat\xd1\x82\xd0\xb6\xab\x9c\x91n-\xc3\xb6}6L-<\x1f\xe0t\x11W0Q\xd5\x031_\x1e\x11\xd9\x18\xbc\x9a\x8a\x0225\xbe\xee\xaa=\xc6\xd6*2|[s\x90\x90\t'
        b'\xed\r3\x9b\\nTT\xfd\x87\x87\xcc\xbd\xf5\xf8em\x82\x8dD\x80\xb3Yc0=J[\x9b\xaar\x87\xb6\xc1\x8d?\x8d\x9a\xfd\xe5\xfa\x17\x9f\x07\xda\xf7\xd9\x9c\t\xb9_\xf6\xad\x1b\x80^\xc7o\x19\xfbS\nb\xd2'
        b'2\x9b\x86"|\x91\xc0\x16\x94\xd052M2\xbe6\x83\xdd}\xbc`\x96^\xe4\x8eNt>9\xc2*\xc1\xe0\xe5`M\n\x06Y|%\xd8\x18D<\xa9\xf6+c;\xab(_\x89=\xb5\xa2\xdf\x96\xd2\x97RF\xc9'
        b"9\x87\xfd\x83z\x08\xf3|\xd7Y\xe5\xbc*\x83M~)\x05,\xac#\xdb3Q\xea\x8cu\xfb\xbe\x1dv\xd6u\x00\x82\x97 \x1b\x88\xfe\xa3L\x8al\xfa3\xdan\xee\x896\x80\xb1\x03\x0f'\xc2_5\x0f\xb2nn!"
        b'V\xb90\x1c\x80\x8fp\x0f\xd9\x81KO3\x959\x8c\xf5\tL\xb8\xcd\x03\xd9\x96\x83\xa0\xf1])\x08\xccqaC\xb4:H\xf5.#\n\x1bdK\xa5`"\xd9&g\xec\xc9v\xf9\xca9\xb9\xbd\xca\xb2\x08\xd0_,'
        b'B< \xc5\xfcQ\t\xd5\xce\xea\'\xbf\xee\xa2?n\xde\t\x8fN6"i\x9a\xa1*02\xdd\xb6:\x87\xac\x9bq%k\xac\xbc@}Wm\x14+w\xf2lX\xe3SIV\x8c;\x9cYe\x18\x94\x14\xe1-!'
        b'A)\xd3W\xc2\xd3\xa5J\x85\xf8{\xd3\xb8\xb0\xcd\xb1R\xe9\xf9\xb2\xa9b\xd2\x9a:p\xc6\x1b;\xf5 \x10\xdc2"\x98\xe0_\xe9(:Jr\x99\xa1\xfd0\xa7\xea\x05\xca\x17\xe8\x99\xf9w\t\xf1\x95\xb9\xb8\x92\x99\x18'
        b'\x1c&\xb4/\x99r)8}\xf5\xa3\xe1\xc3\xd0\xd8\\\x96\tx\x8a\x1bl\xbeQ\xb3\xeb\xb8\xfb4\x9e3\xfbQ5oW)h\xce\xc5\t>-\x04&B\xdb\xa6a\xef\xbf\xbf\x01RR\x8b\x85s\x96\x06\xc4\x8a1\x86'
        b'\xf1\x94\xd9\xea\xae\xf4hdn\xb2\x9bU\xa7}\xa8\x80)D\xdf\xf2aJR\x0f\x10\xb7\x84\x89\xc9w\xffU\x18x\x943E\rC\x02I \xed\xe5\xc3]a\xa2S\x84u7\xa1\x1c\xf8\xe6IN\xac\xa6i*AY'
        b'a\x90\x9e\xa7]N\xe9&\xe1\n,t\x90R\xb5\xe3\xb3\x17&4\xeb+\x94)3\xf2\xd3<\xd1\x9e\xc6\xc5\xe1,\x8c_\xf0\xe5A\xb63\x98s\xf1\x0b\n\xa8N\xe7\xff\x14\x99\xea\x98]1<x\xee\x84\xa8\x82\x05\x94'
        b'K\x7f\xdc\xa5cN\xb2\x8b_%\xf3\r\xdd= u\xc4y\x8f\x8bFbm&t\xae\xd608\xaa\xab\xcf\x95\x17\x00\x02\x08\xbel_\xc07\xa7D%E\xb3\xba\xcc\xa0\xc9>\xa9\\C\xb0o\xb4\x7f\xcf\xe7Fb\x07'
        b'l\x10=\xaa6\xab{\xa3\x96\x0b\x85\x87^\xb1\x1cs\x18*\xbb\xd8Tg\xbezg\x01m\x1c\xc6g\xd2w6\x80\xe9\x05\xf3\x01\xc7\x01\xa0\x89\xb5\xa7sy\x10\xe2\x1b\xf5\x0e:\x93\xc6\xa9E\xa0Z\xa8R\xc5\xa3\x0cz'
        b'\xc9\t\x99wLc\xda\xa2\xb4\x17\xed\xe2>R\x82\xe6\x8f\xfd\xf1`\xeb?\xb4\xcd\x16\xfb`\x8e9wv#x}\x80\xef\xa9\x16\xbcN@U\x92O\xd2<\x9e\xe3L\xee\xeb<\x1ev\x87$\xc7\xbb\x8c\x04\x0f\xf2\x84\x13'
        b'\xfe\x9d\x82\x17\x8cX\x19z\x96&\x9e\nz\x1dl\xa1\xbb\x1cT\xd4\x89o\x06]\x0bRnp\x96y\xdd\x17,\x13\xd8"t4z\xc0\x9b\x0f\xf4S\xaa8\x141fzi2\x01\xe8\xb1\xd8{\xe5\xa5\x97\x03H\x8a\xc1'
        b'\xea\x8d\r\xf9\xce\xd4\xc5\\\x1a}c\xf5\xe1\x06\x1f\x12\xfe\xe3\xa6\xcc\x90\xe2\xf4\xefogG\xcfZD\xbdV9bz\x946\x95\xb4\x0b~\x87\x88\xb9\x05\xac?uaFh*\xef\xdd*N\x1b=\xbd/I\x802T'
        b'\xd8\x8d43\xb5n!\xca\x8e\xc5\xd6\xf8`\xb7t\x8d\x85\xf8\xab\xecc\x87_Sy\x15U\xff\xb2\xe6Uz\xd6\xda\x85/Xg4|\x9eV\xb0@\xeb\xffs\x18\x84rv_\xa3w_\x9f$\x97\xca\xc2\xd9R\xf4n'
        b' 4\xec2F\xe2\xa0(\xd3U\xdb\x08\xbc\xb4\x01\x1f\xb9b\x0bP\xd8\x862\x9a_p@P\x15\x8a\xbd\x10+\x0e\xd2\x14\xdc\xebj`\xa7\xfe\xbfk\x06\x05I\xc3t\xb4\xf6\x0b\x94Q\xf3\t\xb0\xbb%\xf1\x91\xed\x0c\x92'
        b"\xa3,|[\x95\x9cZ\r'\x9c\x9e\x16|F\xe5W\x15\xa9\xea\x9a\x04?\xf95\x8d\xaa\x8f\xb1\x17s\xc6\xc2\xef\xa85\x98F\xbc\xf6\xa5sk\xdb\x9e\x04=\xd0\xb8W\xbd\x0c\xb36\xfb\x90;\xfd\xb5\xf0\x1d\x87}*\xe2"
        b'\xaa;\xf0\xbe1\xc7!\x1f\xbd\x04\x05\x7f,i\xbb\x84q\x92\xa0Z\xc6\x04\x13O\xd8\x95\x01\xfa\x16\xdb^[\xa5\xdd\xdb\xd7V\xde(\xd3\xe1\xcd\x93\xef\x80\xcb\xedo*\tg\xfe&&\x92\xe1\n\x8c\x87( \x1f\xf0\xc0'
        b')z\x80\n@\xfeaV\xa4\x96\x8d\xa7\xc4^jX\xf5\x94\xc2}\xdfZ\xd3\xd580\xed\x95\x9f\xa8:\xf0#\xb2I\xacC=\xcc~\xfb\xcc\xfah\xe7[TX\xba \xc8\x95\xba\xfdi\xe0\xb8xt\tod\xf7\xae'
        b'\xd1#\xea\xf1\xad\xfbz\xdb\xc3\x1c3\x9a\x17\x8c\x06\xe5\xdbhNjA\xcb\x17\xcd\xb3l\xebE\x17E\x98\x85\x08\xa2\xa4\xb3\x00\xde\xca\xac\xefW\xa2\x98\x98\xb6m!:H\x17\x1bm\x16oi\xa5A\x1b\xaaQ\x0e\xfb\xb6'
        b'\x9f\x86\x82\xe14\x12\x14\xaf\x98v&\xc4w\xc51\xdd!\xe2&\xc1\xfd\xdc\xb9le\xcc\xf7,\x0fB\xffq\xc0\x04\xe5D\xfe\xcd$-\xdf\xffZ\xc4\x196/\xce\x84V\x14I\xd8\xbaI\xdbF\xbe\x19\xe6$=\xa3K'
        b'Ch4MX\xae\xf6K\xdc\xd4\xb4V\x1f\x10\xfd\xbb\xb7\xd1S\xdf\xa6\xb7g\xb1\x19\x9d\x12w 3^i\xc3\x89\x89\xc8\n\xe4}6rG\x0e\x93\x8d\x95\xa0`\x06o_\x9bY\x13\xf1:\xb6Q\xeb\xaf\xc9\xda\x0f\xd0'
        b'\x15t\xd6\xa7\xc0\xc8">\x8fV?\x153O\x0c\xc4H\x80\x15\xf1\xc6\xa1Ic\xf5\xe2\x9a\xb8\x03@\xb8\x0f\x8b\xe9A\x10A\xba_\x19\xc1\xf1\xc1\x17\x12\x08\xb8$\x1dd\xb5\xe2\x1az\x10?\x13\x84\x15\x8fN$rz'
        b"\xb5\x93s\xadu\xbc\x07\\'\xfeWeB\x80c\x0c\xb8\xecG\xfd\xe0\t\x1b\xad\xe3|7gD\x08\x9e=\xf0`\xdf*\xfcO\xf16Y\xa22\xb0\x88\x92\x7f>\x00f\x1c$>d\xbb|\xa2\x0e\x8c\x8d\x92\xf2\x9e\xbe"
        b'b\xef\xf3\xc3\x83:\xfa\x8f\x1a\xa5\x93c \x88\x88Y#\xa5@/FWon(dQ\xa2\xca\xc0B\x03\xf0\xfe\t\xbd\xf4\xd9\xd8\xbe\xfe\xc2\x95\xe6\xc9\x15i\x87\xe6\xcb\xb3\x95\x91\x15\xf5A-\xa5_\xb06\xe0\x174'
        b'\xbaU\xb8\xc3@\xe8Z\xb6\x1c\x1b\x1e\xe8\x08\xf0n\x00c\xd1\xbcw\x89\xf9%6\xf1}\x05L\xce\xc3K\xb2\xb1F\xec\xc2\xc6\xbcf\xf6\xf4\x8aT\xf1\xd9\x1f\xf8\xb4uIz\x96\xba\x93\xc5H0\x83\xa6^\xbb\xadR\xf4'
        b'=l\xd2U\x85N\xfa7"\xf1g\xe9\xa31#\x05\x19m\x06\x10\xfd\xfb\xcak\x05Y\x02%kTV\xfa\xdf\x91\xaa \x18\xd2\xf6C\x8e\xceV\xdafg\xf1\x93!o\xff\xcb\x9c\x16\xcfg\x02\xc0T5\xa3\xc4lX'
        b"\xb9r %\xe7JV\xfd_\xd9)\x99ZP\x00\x06<p\rJ\xc0o\xb6\xad\xd9\x82\x03\x8bL\xbcA<\xd9E\x0b\x85z3\x16d(\xd4\xd9\xf9\xd6\xa2\x12p\xdf.\x0c\x90d\x1b\xb0|\xa4\xf6\xb9\xa7\x8a '\xf2"
        b'\xb1\xe8\xd1\x88\x10lg\xbd\\~gOK]\xeao\x10V\xb7"\xec\xd9\xe0i\x80\xaeZ \x91\x08c?%\x11\xfa+\xc0\xe6\xb5{Yng\xe9\xb5\x81\xfe;\xf3\xb8\xef\xfcm\x06aZ.\xcfe\x16\xae\xb0\xbd\xe5'
        b'\xbf\x9b\x88\xf1\x9c\xa0\xedT;R\xde\xb9\x0f\xf4Cg\x003|\xfe&~Gf\x98\n\xb5\x0e\xd4\x84N\xf9\xcc.\xc7h\xaa{\xf2\xd4f\\\xe9\x10\x8f\x16\xcf\xa74~\xea"k\x14\x16\xc4\xa9\x98\xae\xf4\x8d\xd0\x8b\xb9'
        b'\x95\x81\xa3\x01\xa9\xf6b"\xc1\xe6)\xca\xa7\xb8?\xc0\xac\xae\x8c\xf2\x08\x11\xac\xf6\xc1\xa9\x01x\xf1)\x8d\xae\xd9\x1f\xf9\x9c\xe2-L\x82mW0m\xe6\xefE\xa8\x8488\xfb/\xad\x009\xd5\xbd\xabh\x16\xb9x\xd4'
        b'\x03v\x1f\x11OkD\x97\xe0\xab\x85b4\xb6\xfa\xf4!\xd8r\x9asuv\x15\x1c\x8a\xbfy\xc6\xd2/\x98;6"4\xf1p"xIK\x17\xf8B\xed\xe93\xe2ob\xd8\xf7P\x0e\xcd\x95\x93?\xac\x98z8\x0e'
        b"\xe0\xa1\x94\xa2\xd9c\x0c%\xd9f\x10\x14\x04\xee\x07\x86\x91\x16\xb5\x7f\xbe\xce2\xc5\xc7\xe1p\xa1\xe3\x04;;\xcd\x99\x9dE=\xe1\x88\x18'I\x1faj\xef\xbb`\x1e\xbc\xd0\x10\x96\x84\xa4[zD\x1eA\x07\xa7\x89\xcb"
        b'\xe7\xa6\xa1d_\xfa\xe0\x81\xc8\x12\xb7\xe9\xebC\x8d\xdf\xedS\xf5\x152\xe2\xe2\xe85\xe3&\x1ft\xd8\x11Y\xfeA\xa6@c\xcfo\x15\xc2\xe8\xf5\x8b\x9e\xd0Jw"\x7flv\x07\x8e\\\x12\xf7\xc8/Y\xab\xae\xa9\xdb'
        b"\x1dq\x89\x1c\xea\xcbAak>\xd8\xd0d\xa3\x9b*\xb2\xd6\xdd\x8c'\x06j\xf5dSm8\x7f<\x1f\x8fH\xda?\x97\xc7~\xbe@\x95\xb7\xb0\xadL\x159\x8a\x92\xb4\x05f\xc5\xed$`$\xb7\xbb\x0f\xd3\\\xaf\x1c"
        b'\xb7\xe3\xe7\x90\xcf\x04WJUd\xb9+\x88\xa9\x1d]\xaa/1\xa4\xeb\x94\xf0|W\xa4\xd2\x85\xa8a4\x11\xc42=\x19y\xb6;M\x02\xaf4\xe7\xf5\xe9\xaeyg\x18k\xaf\xd6\x04\xc7\x7f\xb5\xea_X!L%\x95'
        b'E*\x87\xb9\x9c\x8dN\x8d\xda\x1d\xca\xb3\xa8#f\xd3Vl^\xa5\xcb\xc08\x07P$,\x0e\xa1`\x87g\xd7\xc6\\\xb7Z\xba\xcb\xc3~\x85\x9a\xea\x02:\x0b\xd9Z(\xddW\r\xbf\xa9<\x05\xee\x13n\xfe\xd8\xda\xc5'
        b'/\xd6\x9d\xd7X6i\x80\xc7$\x0bc\xd1\xd9\xc5\xe0\x03\x04\xe8\xf9\x0b[\x9a\x0c\x97\x994\x94\x98b\xcc&U\xfd\x9b\xb8\xb0TR\xd1X\xaf\x13]\xf3\x95\xbcR\x9e+0\x05c=\x8b\x7fL\xf1\\\t\x95g\xb0?'
        b'\xdc\x1e\xf7\xc3J\xc0Q\x93o\xfd\xc8y\xba\xb81\xd6={\x94U\x10\x95\xde\x99\xb6\xadM\xac+F<`\x99(\xe3M\xa3\x1f\xb8\t\xc2,\x9b\x87\x03<\x88\x98\x9dFL\xa5\x14\x86\x83\xddC\xeb3\xaf\xf2v\xaf\xdb'
        b'\xee\x9c\xb2\x15\xfdq\x16Su\x07\x05\x7fG\x1c\x8f\x8d&\xc8K\n\x06)\xa6V\xe1\x02\xa3\xb8V9=\x05\xd9\xdf1\xdb\xb9\x03\xe8\xb0!\x0bWN\xaf\xa2\xf0\x01\x08\xac\xb5\x88e\xbd4\xb4\x9bY\x8eC69/\x8b'
        b'\x90]\x8d\xd9\xfdZXwF<\x8f7\x1fXV\xd3\x84\xb7c\xcf\xf1q\xa7\xe2\x8b^dr{\xe3\x85\x96\x17P\xf3iz\x06A\xd1[\xbf=S\xb3Hp\x1c\xdemCA\x15[\n}k\xd1,\x82\xcc\xfe\x12T'
        b'y\xf10d\xfd\xd5~\xe9\xd1\xd1j\xf5\xa9M\xdeal\x10\xa6\xe7\x04~\x96\xf3\x9b\xaaq\xc8\xd5>\xbe^\xc3\xc8}s\xd2\x04\x1f\xc3E\xe3W\tKX\x1drN\xc5\x8d\xe7|e\xa8z\xf9\x08\xb8\xf6\xbdu\xb5\xd2'
        b'd\xb1\xef\xf60*G\xccA\xadY\xe9?\xc9]\xce\x0f\xf9Pb1\x9c\xaf\xdf\xb9\x02g\x97\xe8g?/\xc5N\xd8\xc0?\xd9\x9e\x97\xaaYd-\xcf\xe0\x16\xc0\xc0\xa8\xf5\x855y(\xb6\xa1\x9f1\xf4*\x9e-s'
        b'\xe0|oD\x1c\xf2\x9d\xaew\xc6\x14\x99\xd0\xa5\xa9\xfc\xd9g\x8f\x04E\xae\x8dr\xd9\x84\x8e"\xa6\xd9y\xf2\xb0n\xa2\x02\x84\xa1\xf7\xe5jAD\xbd+\x07\xb5\'\xdcb:==\xcd\x9c\xc3\x8by\x13\x0c`\xe2\rW'
        b"ID\xf4\xf7\x90DRG\xf1\xaf\xb4\xe2F\x9b\x9a\x89C\x04\xc5\x93(\x16'\xaf\xb9z\x8f\t\xf1\x02\x01\xb8=\xd2\x04\xae\xeba\xd1\x94TL\x7f/\x9b\xa8^\xba\xd7Kr&{|\x9a<\x1e\x82#e\xaf\xd1\x0f\xd2"
        b'{k\xe2W\xe9<\x1e\xd9\xe45\xa0\xd3x#\x03\xac\xael&<\xaa\x98\x93\xbbz\xf8]\xeeX\x11\xdb>\x19\x11\xb0\xaf=\x97M\xb0>\xa9\xc8d\xfbYZ\x9d\x0f\\z\x00\x05\xee0\x9aG\x1f\xfe\x0f\xc9\xc7E\x1f'
        b"\xcad4\x8df<\x05L\xf5\x86\xa0\xe6BhL\x99\x07\x96\xc7Y*\x05\xd7-\x9b\xca{\xac\x99\xb1,\x84\xb0\x05\xd2Fy\xca\x94Vi\x0b0\xf0n\x00\xcb\xad\x925\xb8\x81\xcc\xac\xa2+_\xb2\xbdf\xef'<\xc5"
        b"\xf5&\x05\x1b\x88\x1d\x93\xc4\x8e\xe5\x10X&\xee\xe2-T#j\x93:6\xa9\x9d\xd5\xa7\x8e\xba%\x8eZ\x95\x0b\x8e\x16\x8f\xd9i.\xb7\xb9f\x0f\xabBv$UQx\xf1\x10\x8e*\xba:\x81'|E(\xebM\xc9"
        b"\x0f'&\x87\xa769\xcc(\xc1\xe2\xe8@\xfa\xcad\xde\x07+\x15\x06\xf4\xcb\xfbRf:\x16\x07\xeb\x1f.i\x99\xd0\x91\x93\x95\x1c\xaf\x80}|7\xb2*\xb8\x12\x01r\xc4\xcb\x0f\xaa\xadj\xb5\xf1\x9d\xf3\xe07\xe2\xca"
        b'\x893\x84\xe82p\xbb\x94\xbe \xdfc9\rvi1\x14#\x1dI\x9cY\xdcr"\xf1;\x82\x07\x08\x92cP\x90(\xa0\xe7u\x8f\x8b\x81\xa4s$\xbc\x91`\xa2\x19)\x1c\x8e*-\xb9\x9b\xd1\xe4\x0e{U\xb7~'
        b'\x91:Li\x9a\xa05\xc6-\xab\x8f\xc8\x12=\xb0\xc4x\x7f(>\xc1e,Y3\x82%\x0e\xad\x1b\xda\xf7\x85xe\xbd\x9b@\xc6\xf6y\xb6" 1\xd3\xa2]\xb2\xdb\xd2\x14\xce\xa4R\xa98\x98\x8aZ\xd6\x85#\x8e'
        b'\x96\xec\xc2\xfb\xa3\xe2\xe6\xc7u\xeb\x1b&}_S\xb4s\x0e\xe6\xe6\x8b\x88\xc9\xe0\xab\x8csK\xe1\xebh\x07\xdd\t6k\xe1\xdd/\x8a.\xb1\xfcQ\xf0\xd1o\xfa>\x95d\xd4B\x83g\xf5\xa7\x0e\xa1\xf4\xd4\xe63l'
        b'\x91{\x01{%\x06E\xe0(\x88\xf5\xab\x98,[< \x9f\xa3\xd6\xafa]{X\x8bh\\\x87s\xc3\xe8\xab1\xcb\x18\x87\xacRF\x93\xc41\x88\xf2\xaa\xfa\xfe\x16$\xd2~\xff\xe3\x95\xa4%\xca\x17g\xc6\x03}\xbf'
        b'\x10\xf0<K\x83_\xdd@r\x0b\xb9\xbb*\x14\x15)Y(x\xe1B\x12\x8el\xb5_\x95\xca\xd6\xf6\xe5\xd4\x1598\x9e\x8b\xb8\x9e%\xe4\xbe\xe5\x14\xfem\xdfm\xcb\xa0\x82\xe6\x12\xf2]\t\xec*\xff\xc5\n\x85\xc8\xff'
        b'oz\x97\xc5[\xde\xdeB\xff+R\xa5p\x81%\xbe\x99(\xdf\xcd6\x9b\xdf\x9fnu\xff0\xcaS\xf5\x7f\x83:\x1d*\xfdV\n\x00O\xcd\xb8A\xcb\x83\x1e\x84`H\xdf\x10\x1b\xbb@\x1c\xae:0\xe1\x05\xc6\xa6\xe8'
        b'\x04\xf6\xcb\xf1\x17Nx\xa7S\x00\xaffT\x0c\xc4^\x06\x14\xd1\xf6R#\xd5\xa0\xf45pQ;\xae}%\x14ra\x0f{\xc8\xff\xf7\x15\xec\x17\\\x17q>\xeeO\xae6)o\x16\xf4\xf9\x18\x8fA\x19~\x0b\xf4\x7f'
        b':#\xc6(\x0c\xaec\xca\xa54]\xfd:c\x00\xe6?\xd4^\xd2A\xc2\xc1\xf0\x99\x13\xf5\x1eO\x96\x05!\xa2\x87\t\xacoD\xbd\x1a$\xae\x98u\x8e\x8dH\xe4\xebD\x96\x0b\xebdi\xde\x98(\x84\xff\xa75\xbfe'
        b'\xfds\x8f\xa0\x978<\xf2\xc9\xff\xbf`w=AV\xaf+iRi\xf4\xa9_\x07\xbf\x06\x03\xec\xfb\x97\xd4\xc0\xe6*)\xc2k\xfc\x1d\xd4\xf4\xf7kXS`\xb2N\xa2-\x0e\x96\xe6Q\xaf\x00H3\xd3\xdd\xd45"'
        b'\xca\x8dY\xe7\xe1\xe2\xd9Xr=\xdcrq\r\x08e\xedl\x96\x93\xe7p!m\xe7\x99oES\x03\xc2z\x16\xe6\x01\xb5\r?\xdc\x10\x19\x06\x83\x1c0\x84h&\x02\n\xaa\xba\xc9\xae\xb5\xedDi\x80\xb5\x10h\x9fE'
        b"\xa2\xf5n\xe8 \x8f\xcf\x95\n~\x8d\xe9^\x04\xe6\xf3\x1d9\xee\xb6\xe2\xe5\x10\xe1\x89\x8cG\x8cC\xb4\x7f\x9a\xd8\xcd\x91'6w|e\xde\xbf\x14k\x0e\x9c\x8e\x8c\xce\x1a\xf5\xea0\xe1\xfc\x82\xd9\xc6\t\xf1\xce_\x85\x19"
        b'\x8d\x11\xb5;\x02\xc1\xc1U\x8d*\xb8\x1e/!\xab#\x142\x19n\xf2^\x99n\x9e\xbf\xfd\xdf\x068_0\x93V\xa3\xa2\xe5p#F\xb7\xae\x85\xcc\x8a\x7f\xd1\nl+c\x9c\xd1S/\xaa^Cl6?i?\xd3'
        b'\x03\x12U\xfd7\xb2\x9e\xac4\xd2\xba\x92\xc8{\xb7\x10\x1a\xf9\xf4\xd7I\xa6\x8az\x08\xb44\xe0\xb8\xa9m\xed\xa4\xcc\\\xb3\x89\xba\xcfm&r\x04\x10\xb1]\x0fo\xcdB\x7f)\x84^\xadV\xe9nd\xae\x16\x7f2\xae'
        b'/#\x14pn\xa9|9\xe5\x8cV\x9eC\xdfa\xdb\xab\xfc\xe6\xcb\xfd\x1f+B=\x85\x18\xb9lOC\x011\xe6\xdc\xe3\xbc\xa5\xb7\x14\x8e\xb2\xee\xcd\xbd\x0e2\xcf\x95l[%So\x19\xa2\x05\xa5v\n\x88\xdf\x91\xe6'
        b'\xb2M\x08\xe5\xa4\xf8:\x93\xa7\x98\xd3\xc1\xe6\xb6\x0f\x80\x7f\x8d\xa4R\xb7\x12\xdf\xdemF~mn\x8b\xea\xbe\xed\rH\xc2J\x8e\x17{\xbf\xdd\xb3q\xe3\x12CRJ\r\xae\xe1I\xdd\xfb\xc3?K1\xcf\x18\x97\xe7\xe5'
        b'\xd7\xee_\xe9HLp\xb1\x05K\xc3\x7f\xc0\xa7\x92\xb4\xd1_G\xff\x08\xcb;\x07\xae\xa5}\x9c\x9b)\x0b\xcd\xab2\x94[\t\xc6\xeb}\x16#\x882q\xdc\x87\xdc\x0f\xf1\xc2\x1b\xe3\x7f91\xde\x0c\x1f(8\xd4\xbdE'
        b"\xe8\xe7\x19\xad\r\x17\xad\xe4\xd9\xea\xd3gM:\x85\x11\x86\xa2\x96\xd4\xe1\xa5vP\xb3J\xf1p\xdf\x12\xf9\x95L=\xf0\x94Py\xfb\xd8\xf5\xf1'S=\x9f\x96\xfc\x15]{\xc6\xa1<\x0e<\x86fx\xc9Q\rh\xd9"
        b'\x7f\n\xca\x06\x80\xd1\x9c@\xf1\r\xa5K\xf2\xca*\xa1\xd5~\xd8\xa5e\xe5]\xd5\xa6\xa1\xc2\xcf\x96\xd0\x10\xa5\xc1\xba\x96X\x93\x95\xa2\xeeD\x10{\xb2\x95\xea4\x95M\x9b\x9b{\xaf\xfc\t\xd8/\x0cJ\x97\x8e\x8e\xb9h'
        b"\x0e\x12_#\x1f\x0c4/'\xb0\x12P*\x07fV/+\t\xc3t[{\xb6\xb4\x18\xd2\x94hk\x80\x1dW\x99\xa0D\x11\xa8\xbf\xbf\xc1\xe7\xe5fD\x90\x13\x18\x85\x9e!\xe5\x1e\xc4\xb1\x85K\xffR\r(\xd9\xea\xfc"
        b'\xd6?\xe3\xb6\t\xe9\xe5\xe0>\x93\x86\x0b\x95\xd6\x88?s(>R\x0b\xbcb\xc1\x88I\xdd\xe1\x93\x16Y:\xfc9\xbc<\x87\xd1\xf4\x13\\\x9e\xd8\xa6\xc9\x95-\x93\x99]\xc2\x925\x99-R\x12#\x94\x0e\xa4\xf7\xcd\xdc'
        b'*h\x1a\xcc|\x9c;\x97\xbe\x9e\x81\x02\x98&\xe9\xadon\xed\xd4\xfeFD0\xfc\xb5\xe8\xba\xfe\x1cX\xa1"\xc9\xd2\xbe\xa6]\xe9,wL}.\xc10\xc3\x8b\xa7/\xfdm\xf8k\x80\x1c\x15\xf4\x86\xa9)\xc5ED'
        b'm\xd93\x80Dn\xc4?X\xb7\xf4"\xe1R\x86\x0b\xd7"\x91n\xb5\xf3\x83\x83%,\xbb;\x99u\x81\xc4\x89w7}u\xdb\xd2\xb8\xd3}\x9d\x19C\x1f\xe4>\x190\x01d\x9di[J\xc4L\xb6\xb1\xb1\x81\x9a.'
        b"U@.%\xf9c\xb8\xa6.\xe9\xe8h\xeeo'\xb9{}\xe0h\xbe\xe6\xfa<\xa1\xf5\x8d\x91f\xf0%,\xb0x\x80\xa0\x12\xceF\x87\xcfk\x90\xd0\xe7\xc3\x17\x0cSi\xb4\xd1\x05\x1d.{\xa3\xef%\x04o\xa2\x96\xfe"
        b'<0\x98\x1bI\xc1\\\xf5\x89\x00\xec\xc9\x83)Q\x01\x7fU\x10\x1ea\xe1\xcd\xad}\xfa\x90\x01\xfeG\x1b\xce5.D\x90\xfb\x98\x8c\xc9\x8a\x987\x9c\xf5\x00\xa1VL\xd5}8F\x95`q\xcf\xff\x9b>\xee\xf3\x9c\x13'
        b'\xbd5\x93Yx\x16\x05\xd6F\x84zX\xca. <E\xcb\xe6\xee\r\x82\xcd\xc3U\xc9%\xfc\xa3T@\x8b\x0fR\xe1\xc3\xb5\x9e5"\xbc%*\xc3\xd5\xbcEL^k\x9e\xda\xc1<M\x89\xec\x04\x8fw\xa8\xe1\xc4\xd4'
        b'\xa6\x82\x174\xf4$m\xc2_h\x90\xadJ<\xf5\xd6\x0f\x0b\x0b\xbd\xb0\x89#P=\xb4\xe6G\nd\xafP"w\xf7\x90d\'\xda\x81(W\xcf\xd1\xedG\x8f\xe4\x8b\xc7\xb66!\xb9G\xcbL\xa0\xcc-\x00\xa8\xcfY'
        b'"VQ\x83o\xde\xdc\xf1\xf7<\xa6\x90{^\xd9)Wo\x91\xf3\xdb\x1b(\xc8e\x82\x9d\xea\xdf\xd4\x1f\x94J\xa0.\xa5\xfe\x97\xfak\x1c\xb2\xa0^\x16\xd4)a\x81\xe3\xba\xa8M.\x1f\xaa\x03Q\x10n.6\xf4g'
        b'\x1b\xc1tM\x9d\xc4\xd2]\xe3\xaf^\xd2\xb6I\x0b\x9c\xb8\xe8e\x17]J\xa9\x17I\xd0\xd4\x1bu\xed\xa1X\xcc\xae\xac*\x91\xa4\x11-q\x92h\xd2\xe0$\x1b\xa6t!m\xb32<\xb1\xeeJ-\xc9\xae\xbb\xa4\x7f\xd9'
        b'\xb3\x07^.\x8a\x17\xa6\x9d\xb4\xed(5RA\xee\x7f\xe9\x97\xa1\x07$q^\x17\xa4\xa1\x96\xc6\xb5\x881\xce\xe4\xe1\xe1\xc5\x8c)\xc7\xa4\x9d\xc9\xf1\xfck)\xa8\x83\x19\\RT6\x91\x1fS\xe7fi\xbek\x01\xc2\xaf'
        b'\xe7\xc73t?\xa7\x1fqm\xceE\x0c|\xf3\xbe\xee\x0c\x15*\xff\xa9\x03Q\x16g\x17\xfd3\xe01<Jd\x13\xbb(\xc4\xd9\xd1\xc9\xef$i\xcb<\xd9\x15\xad\r\xf6\x02&\x96\xdf\x80\xfb\xc4\x84<\xc5,\xbb\xa7\x05'
        b"\t\xb8QW\xd9\xcc\xa3\xa4\x08\xcd3W\xa1\x08\xb6\xa3\xc0\x88\x9c\xf2\x02>\xbd\x05:\xd9Ggu\x1f\x90'\x81M\xb8X\x85\xba\x7f\xd5\xd8\x9e}\xcf\xad\xb2\xb7\xf0\xed\x9a\xbf\r\xdb\xd6\xd0,\xad\xfdW\xb3xA\xfb\x07"
        b'\xd1~Wo\xdfL=\x19\\1\xbd\t\xd1\x9dTS\x99L\x82\xe6+:\xc1\x11\r\x9f\xdci=8\xe5;\xe8k\x86\xb6L}\xbc\xa85\xef\xfd\xdf-d\x1a\xdf\xb0\x18\x939 \x9f\x15U(\x99\x7f\xc6\x88\x1d\x85\xef'
        b'\xd4H0\xf5\x84T\x18{(r0\xbd\x12\x98-\xb0l8\xf3C1\xd4#\xea;\xee6M--J\x12\x9c\xa8\xd5\xcc\x8b\x17\x08\xc4Z\x1a\xde9CA\x17g\x00Cw\x97\xebnB(_cJ\xadV\xeb\xbf\xd2'
        b'\x98\xf8\xe7$\xd9\x1a\x7f\x1d\xf3\x8e\xc0R\xd9\n\x8e\xb2\xdd\xb4\x8a\xeb\x9d\xc4\xc7\xbb\xad_>\xf0\xd7v\x96"\x9aLHC\x8f"6N\xfe\xf0i[\xffM\xb9y\t\xfa`\xde(\x1e8IM/\x08\xdd\x1d\x9cc\xac'
        b'\xe9p\xf4{\xbb\xcdx\xb1\x8d\xca\xea\x88\xffs}\x88\xc0\x06\xe0\x8c\xdf\xaf\xb2\xf1\x8eh\x99\x1ey\x87\xf2\xf6\xf9um.b\xf3\x90\x1d\xf0%\x01\xa2\xb82^\xb9_{Qn_`r\xb6\xa6\x168\x05\x048)\xb4'
        b'\xa1\x18\x98\xdbf\x1e\xb7Y\xca\x96\xa7\xd9s \xdd\xc2\xf2NL\xe6y0\xbc\xbe\x93\xf8\xfbt\x1e\xcb\xaf\n\x15\xfa5j^\xdc\xfe\x02\xe6o\x85u\xe5\x12\xd5\x8c\xc0\xe86\xb9\x1a-\xfey\xfa\xdb\xf5 O\xb73\xcd'
        b'\x9d|(2V\x05DU/\xec\xe2\xc9\xa0\x89\xa1\x0f\xf8\xb9\xdfl*\x0ezP\xa2\x8ew)\xe5\xd9\xb0\x828@y\xd2l3\x80\xde\x847_\xa89\xaf,\x07W\x97s`+\x084\xed\xac\xe5\x16A\xdf\xf4\xfe\xcb'
        b'hkOe\xa8Y\x02\x1b/F8\x7f\x02l\xdfs\xa0\xa4\x19\x11\x82@F\xaa\xce\xc5\x9b[\xbb\x9c\xcfo\x16\xbaA\x9eW\xb4\x9b\x8dF\xfdA\x02ory\xac\x8eF\xf9\x95\x1dg\xd0n\xb4\xaeUQ\xdd\x17\xfd\xe0'
        b'\x0f\x15\xd3\x03!\xf9\x86\x88\xa9\xf1\xaeu\xce\xbb\xf0\x0f\x85\xb0\x005\x89\x9c\xad\xbb\xcb:i\xe1I\xb2W\xe4<\x00\x90{\xd9U\x98\x82\x9f\xc7\xa1\x80\x86\x86\xf4\xa4V\x8e\xb6`\xf0$St\x07\xc0\x8a\xb4l\\d\x9a'
        b'R\x92\x0cJz\xe5j\x8d.cr\xf0~\xae0\xc9x$\xe0\xd4\x0ff\xd0\x1d\xd1g O\x0bS\x9d\x90O\x1c]\xd3\x08\xf8\x84\xac{\xab@\xbe\x05r\xb0\x07\xcd\xdb\x1e#\xd8`\x03\xcb\xcf\xea8-n\xd8j,'
        b'\x90\xa1\xd1K3" \x8c\x94\xd28\xbdD\xffW\xf6\x94C\\\xde\xc3\\\x98\x10\xee\xbd-\x7f`\xeb\xa12\x14\x95\xe6\x8a\x9b+p\x96\xe8\xfbL0C\xadm\xb0 ?\x0c\xbe\xee\xbc\xf1;\x0e\xfd\xd7\xa5\x1c\xdcxM'
        b'9\xc0M\x9f\xd8\x03\xaa\xb3\r\x82A\x84\x9c\x0b\xed9=\x9c\xec\xac\xe69\xe0\xed\x1e:\xe9\xb2\x80\xd7\x81\xfa\x1e\xe5\xd7\xf4\xc1\xa9\xe6\x81\xec\xd8.\xec\xc7\xd2z7\x12\xc2\xa1Ml\xc8\xe4\xdd\x8fL($\xb4\x92Re'
        b'U_\xa7\xf2U]\xdb\xe18\xb3\x16\x87\xf2}8J\xf4\xe2\xd5V\x9f0\xa3\xa2h\xc88\xca\x1d7@\x9fn\x16\xec\x01\xfd*\xfb\xed\x12\x01\xd7\x1e\xc0?\x15\xf4\xb7ry\x14\xbd\x03\xdd\xf8\xfc\xf0H\xc6\x93cz\xb0'
        b'\x8b~\xdak\xec\xde\xca\xd8\xe6\xd5\x10}!\xdf1P\xc6\x1d?\xca;w\x12\x81O\xc4..\xcb\xa6\x1b\xd1y\xfba\x86\x9e(\x02\xbf\xddV\xa2/\xd2\xe4\xb9\xf8j\xdbF\xf2r\x9f\xb9\xbbP\xfdh\xd5\xb1\x9e\xbd\xf2'
        b'\xc2\xb5\xdcv\xa1\x82\xa6F3\xd3G%+\x16.\xdb\xd6\xdd\xce\x05\x1d8\x8e\xden\x03w\xa4\x85\xb9\x0e\xb8{\x96\x01\xa3v\n\x8a\x93\x8aQ\x0c\x85\xde\xa6E\x08Ig\xbb+3\xa4h\xe3\x88\rP\\\xc7\xf7\xfb\xd8'
        b"\xd1XdvxTt\x04a\x0f.\x03\x18\xcd1I\xa7\x9f\xc5e\xd1\xeeM\xcc\x84\x02\x9a\xd8^\xff\xe1\xa3\xf1\x10\x96\xb3'\\A\x0c\x0e\x88\x89\x18\x17+HtI\x8a\r\x8a\xc6\x95\x1d\xf3L\xa6\xbf?\xf5!^\x0c"
        b'\xdeq6$\xefkH<Z\xf7\xf6\xa9\xbc$\xc1\xf9T\xa6\xbc\x857<^?\xf6L\xea\xbdX\xc5\x8fQl\xe0o \x06\xdd\xe0aN"\x9bK\xf0r\x1f6Ql\x88\xcf\xf3\x0f\xfa"\xac\x9b\x85s?\x82\x9e\xe3'
        b'\xaas\x9b2\xce\x18\xba\xb6\xd1m6\x85]\x82Ha\xa4\x8c\xdb\xe6bm-k\xf1(\x8a\x06f>\xb6\xa0\xfccn\xd6\x1a*\xb1v\xea\xe8t\n\xa3\\xD?\xc5hWB\x03YXt\xe0d\x8c\xeaX\xbfX'
        b'\x1f\x1d\xa7=\x94\xa4\xe9<M\\_\xe3\xd8\xafN\xf6\xe4\xc2\x83%\xc5B\xe4?>\xc3\x1f6fY\x89\xf24\xc8\x93C\xadz]\xee\x1d\xe7\xf4\xd6.\x17\x81\xf5\x86\xd7\xbd\xdc 0U\x0f\xef\x12X\x90N\x9f[.'
        b'\xc9\xb7\xa2yF\x98\xc2\xf9\x0c\xd7y\xe1\x90\xcb\x9e/\x97-#\xfe(0\xa8Z\xde\x1d\xf5\xff|\x1ap@\xd2\x14\xa1`tJN\xa6*\x06\xb4\xbe\xc0:\xca\x11<\x10~ux\x0f\xa8\rt\\\x9c\x93[\xfd\xde2'
        b"\xac\xb7\xfe]>\x98\xe1\x9d2\xf8\x95P\xea\x8b_\xc9\xea\xaep;\x97\xcdB\xcb\xd8O\x9a\x99\xca\x9b\xd7\x0e\xcf\x0b\x19\xeb-\x98\x92\xbd\x89\xa9]\xb1\xea'\x1a\x1f\x8b\xb6\xa62bWR\xec\x82~\x9f'\xda0RL"
        b'\x1a\xb6\xae\xb5\x13\xf5^ca\x0b\xe7\xdc\x83\x8aL\xea@\xbd\xdeP\x9c\xfe4\xa1V\x97a|\x9d\xf2\xba\xe7\xbf60|.\xa3H\x8e\x8a!"\x93\'i\x01\x0bUQ\x00\x8d^1\x12+\xe9\xbaQ\xa0\x9c\x84\xc7\xbb'
        b')b\xa8|\xdai\xcb\x92\xfc\x85\xba\xa8\xf51l=gh\x91w,"\n)BI8\x8d[\x1e\xfa\x19\x7f\x1f~\x97?I\x8e\xe8^\xa8\xd5A\x15\xf9fv6J%%\x01\xe6=h\x8e\xc3\x15\xe7\xa6\x84G\xca'
        b'\x01Hv\xae\xf0\xc7\xc1\xe2\xce\x03\x1f\xbdM%\x91:\x90\xd9A\xf8v\xa4\xd7%\nV:\x9b\x10\r8=\xef\xbf\xf5U93JUn \xd5z\xd6)\xde\xba\xe3-G\x8dc\x19"\xb1\x7f$\x1c\xf0\xe9\t\\F'
        b"\xdc\xdaN\xd1\x8c\xc6\xa4wr\xbeH\x02\xc9\xf2C\xf0W\xead\xcd'\xd0Nl\xf0d\x9f\x01\x87\xc8LX\x00\x1c\x88\xa2O\x7fl0;\t\xee\x12)\xc3\x1aW\xfc\xac`\x10e~\xe9j,pbAz\xf8\xff@"
        b'\xf2\xf6k\xd0,\x9e@\x18\xb6g\xba\x12\x925\xfd\xf7\x16\xed\xa5\xefY\x9eq\xed\xa6\xe1\xc4\xa1\xde\x1b\xf5I=\xf6D"\xd4\x83~\x99\xeb\x94\xde\xfeA9\xa8$~\x89\xa2\r\xb5l[sg\x98.J\x9a\xa9\xc3j'
        b'\x03\xb1>\xfb5\xc2\xec\x87\xec\x16\xf3_\x9aD\xab\xb9\xca,\xb39\xb8\xb9CcX\x7f\xeds\xb7:\xdcv\xbc\x80\xb8\x90U\xf8\xd0\xc4\xfapo\xf4\xaf`-\xedD"\xa8\xf0(\xdf\x82]\xc4&$\x01\\\x93\x8b\x0b'
        b'\x0f8\xc45\xf6\xc5\xef&\x98!3z\x0f\x8d\x036\x1b6\x14\xa5$~\xa7\xb8A6-!\x93\xc2\xe7\xa0\xc3\x0e3\xbb\xa7\x1b3_:1<j$\xb3\x89\xe1)A\x89\x89\x814W/H\xb5\x1fh)v\xa1\xa5'
        b'\xbd\xce\x1f\xa5L\xf3\x19J|C\xd3\xb0\xe8Q\x19\xda\xd5\x8d$\x12\x01\x8a\xd6j\x89x\x0c\xa9\xcb3\x07nQc\xca\xf8*T\xf7\xee&\xea&\xdb\xed\x8a\xe55\xe0\xeb\xf1`\xcc:\xbd[\xf8\xb8\xff\xc4\xd0\x7f\xe9d'
        b'\x05zcD&\xc8\xb0\xf2\xb8\xc53r\xfa\xe9\x02\xa8\xb0\xad\xea\xe2\xb6\xfe5\xe7\x8f\xc8h\x19.<\xac\xd5\x9a\xba\x95\x88\xecx\xc7,>\x0e)\x90\x01\xfc\xb0\x87\xcf\xf2\xdby\x17\xd3\x08\xd2\xb8\x05\x13\xdd7\xdb\xb1\xa5'
        b'\xf5",A\xdf=\xfb7\xe5Vs\xa7b~O\xec\xd6\xbd\x83\x1d\xed\xca\xfd\xaa\xfc\n\'\t;\xfe\x88\xf9\xa1\x82\x17\x8bdtZ%a\xfc13\xc0^\xdaAV\xd8\xf88\xa2=\t\x83\xc3\xe8\x10\x10\xae7\\\xe4'
        b'\xc8\x8e\xbc\x1a\xb8\xc6<\x13I\xa4\xfdC\x12\xcb\x06W\xf6\x84\xfe\xd9\xdf[B\x95\xdb\xb51\x95\x9c{m]R\xa2\xacf\xfb3Q\xc8\xa8\xc4fM\xb3R\xca~D{\x8f\x07+n<\x9c\x94X\xf0\x9f\xb39\xaaZ'
        b'\x9aK\x7f\xc0\xc6M\x1eX\t\xec\x93\x9a\xf9f\x8b\x98\xd4:\xc5\r\xf2J\xfee7Z`\xf4y\xc6\xae\xa9X\x87\x94\x1c\x92?v$\x025[\x0caw\xa66}\xcf\x17n\xdd\xc2V\xe3\xbb\x88\xa1\x16m\xdf\x1f+'
        b'\xd1\xfe\x1c\xd9\x8d\x08;\xa4\xdf\x1fXpk\xb2Q!*\x89P;\x98\x9ev\x0cu\xd7\x83\x06\\\xa8\xfbV\x84\x8b\xd9$6\xa3\xca\xd3\x88\xf7V\x19\xdc\xdba\xcd\xe6\xde9]C\x01Y\x96\nqQ\xb3\xac`G\x86'
        b';/\xf7\x05\x97A\xafS\xba\x99\x0c\x98M\x15h\xb3_s\xf7P%_Gu\x86\xc7\x8a4\xad#)!\xd0\xdf\x7f\x1b\x8f\xc4D\x80&\xc0\x9d\x9a,=5-Sh\x10\xc5\xbd|\xc5_\xb8f\x8b&\xfa0}\x9e'
        b'`\xb0\x03\xa8\xa65\'\xef\x93::l~\xef3\xd93\r\xb7mum\xa4\x89\x00fU\xe98\xd9\xc2f|\xb2"\xa4\xf0\xed\xe0\x10\xa5j\xcd~\xdb\xb4}\xb1[\x86\xdd\xa7\x1a\xbb=\xdb\xd9\x06\x9ft.H\n\xc9'
        b'\xf0\xb4N2\xb9<Xq\x98\xbd\r\xe6\xfe5\x13\xbf\x9ba24\xa6\xd7i.\x00%F=F}b\xfc\x16I^\xf4\xebs\xd3\xb2\x01?\x12\xa4\x14?F\xd6\x88\xb1\xe7\x9a@N\xf2\x8e\xa8\\\x9d5w\xee\x9e\x98'
        b"\xf9\x80\xe5\x8c)1\xfb\xe0'~\xf8j\x87\x82\xdb~\xa1a\xd6\x7f\xb6\xea'\x8c\xc7k\\\x9bS\xd3\x91\xb4\x12Z\xdc\x11\xe9m\xdd\x95\x9a\xe0U\xc6\x9d\x8a\xfa\xc6\x97\x9a\xfa\xb3%AG\xc1\xa4\xaf\xa2\xea&(,U"
        b'\xc9\x7f\xf4?\xbe\xc1\xc2N\t\xb8\xf9\xf5E\xfa\xe6\xc8;\x8c%\x1c*\x02z\xd9\xe4u\xc1\x8bn\xd8"\x84PCNo\xa4b\xbf\xc1\xc3.\x9a\xe6\xcb#x\xe9\xaa\n\xb6\xee\x87.\n\x0b\xd2\x99\xb5\r\xfb7\xee\xe5'
        b'h\x13\xf0\xf6b\x00\tQVH\x99\xbe\xb1\x93Q2q\xec\xa2\xc5s\x10\xf0\x07\xafr\xa7\x0fF\x05\x9e\x08A\xa21\xcf&\xd2\xbb\x01\x80\xa2\x90\x05\xa0\xf8\xf43R#$ DY\xa4@\xd2\x114\xcd9qYv'
        b'\xcf;;\xfc\xff\xd6\xb5\x84\xf9\x0b7\x03\x89\xfd\x155\xf4l#\x9d^A]\xb2\xd6\x93t\xcd\xb9Ds\xfa\xf0;\xd5s\xfb\xc9\xb7Dl\x04\xcbk\xd8<;\x84\xca\xa56ft\x8d\x90n+)~\n\xfb\xc2g,'
        b'A\xe6\xcfn.\xb6\xfa\xcb\xeel\xd5\x1f\xd5y8\xd3\x85\xa4\xb6\xc6&8*\xd5YcY\xfb\xa7,\x7f\xea\xb5\xdf\xe0?\xd2\xc1C*\xb8-\x07\xa9t\rQF\x9a\x9f\x0f$\xe3\r\xa7\xca\x937b\xeb(\x83\xa8>'
        b'\x0e\xc6\x96:&\x95\x0b\x94\xbaJ\x98d\xdf\x97fB\x13\xbb@\x81\x145)eyV\xb3#O\xb0\xa7\xc7~\xe5\xd5\x83\xd4\x0c\x95Uk\x1bt\xc3E%\x18\xfc\xce\xf2yM\x92\x83_"\x0f\xa4)\xc3i\xbc\x86X'
        b'\xd5Ww\xabE\xf0g\x16R\x1f\xf7\xa9\xea\xcb\x9d\x19u\x12\x8a\x8c\x87\tzi\x0c\xb2\xd3\xc0\x05\xa8\x94s:F\x1b\xd6l\x1e\xfa\x9c\x08\xa7Et\xafR\xad\x1ai\x04\x8e\x05v\xc2W\x0c\xd7\xf2Y\x0e\x8df\xae\xdd'
        b'\xeb@\xa34\x8fB\xb8\xc0\x81\x91\xe5Sba\x946\x989\x91\xc9o\xdcmyLA\x1a)\xb8\x05\xb6\x8a\xeb\xd0\x97\x17\xc1\x9dQ.7s\x89\x9c\x1a\xbc4\xb0\x10?5Q\x12\xcf\xceb\xd8\x12%\xd3\x99\tD.'
        b'\x1ai#\xcb\xdb\xec\xee]\xf5y\x0f\xbf\xb2\xbc<\xeb\x02x\xdc\x86\x8e\xf6\xfe\xbcg\xfc%\xc1\x12*\xcfwF\xc2y\x0b\x0el\x00\xca\xa10"\xa1\xed:\xb4l\xb3\x04\x18\x12\xb9\xb6\xbe\x0c\xcf$\xc0|\xd2\xf4\xbal'
        b'\x13\xdb;U\xdbn\xf2E\xe37BF1\xc5>o&\x11\xb5\xebk\x88%\xf8\xe8G\xb5\xcf\xfdY\xc9\x11\x03\xab\x03\x92:\x0f\xca\xbe3\xc0ca\x8e\xe78\x1bf*G\xf9\x9cO\xca\x17\xca|\xa5i\xcb\xe1O\xc4'
        b'\x84\xe6\xdb\x0c:\x15\xc0\xe6\xd1\xc5\x90\xc8?_^\xa7S\x1f*\xc8\x03\xfa\x90}\xaf\xcfN\xee\xc3U\xe1{1\xd8/u\x83K\x9c/\x1f\x9e\x90\xe0\x85\xc7\xebYi\xebs\x16\x98\x19\xc3\x92\x01\xc0\x17z\x00\x92\x1b\xa7'
        b'_\x0b\xa3w\xf3\xc7\xec\xd5\r\xbc\x8e\xa6\xed\xd8\x9f\x10\xd9\x83\xa3 \xfa\x8f\xe3&\x98\xba\x0e\xe8\r\xb9[\xedV\xd0\xd8V\xf4\x18}\x87\xc4\x07\xae\xd6\x8c\xbb\xc0\\\x81\xb8\xa1vy\xbc\x18\xb7H\x98@-\x8a\x04)\xdd'
        b'\xd5v\xec\xae\xd5\x98\xc7?\xfe\xf2\x93\xa9\xc5\xb5\xe7\xf6by\x02M\xbdsdU\xbe\xaae\\X2\t \xb1q\xbfM^\xde\xc8\xa1jn\xf0Il\xa5\x92\x94\x9c9\x00AO\xa5\x8e6C\xa8\x96\x03X\xcdN\xaa'
        b'\x8e\xf4\x8b\xdf]\xd5L\x1e\xca&m\x0c\x91\x92B\xbaN\x05\xee\x11\xf73<\xeb\xfet\xc6~\x8b\xbf_l\x1d.\xb5\x83\xcc\xeb\xa7i\xcd\x07\xd6\xf6\x81\x98\xde)\xc8\x8e\x96Z\xb5\x93\x7f\xf9\x83\x10\xd5\x13\x0fo\x16\x06'
        b'\xf1\xbc\x8f\x86\xedd"\x01\x8f^\x8d\xafT\xceB|\xa2h}u>TB$\x82\xc2\x07\x85\x0cJ^\x97@@\x14\xc2\xd2\xb6j=\xd0\x9b\xdcZ\xe9\x19R\xde\xb0\x0eD\xa8\x11\x18\t\xd8\x83\x94\x96G\x91\x14\x1c\xa9'
        b'\xb6\tG4\xe6\x84\x05\xce\xcb&\x0f\xad\xa2\xc8hb\xef\x8aW\xaa/rv\xb8\xc5\x8f\xb3\xa9u\xe0\x12Wl\xd5\xa7-\xb6\xbc\xac\xeb!\xdc\xa0\x92l\xbah>\x90^0\x13\xc0\x94\xa9\x07\xe3\xa3D_\x7fs\xe1\xfd'
        b'\xb6dC\x8f\x92\xc1\x89\x99\x95\xee/,\x86\xace\xdb\xeb\x05\xe3\x93\xac\xad^mS\xba\xfb\xf9#\xba$9\x9c\x10M@H\xcc\x80\x93\xf2C\x9a^\xfd\xae\xc6M\xf1pD3\x9f\xa0:\xc8`vd\xb8\xc0M\xc7\xe2'
        b'\xbc\x8fP\n\xa7lG\xcfkg\x1f\xcf\x83A\x15\x9d\xa3\xbbkD\xf4\xe7\xa4iq\xab\x7f\xd5\xabb\x10\x06%\x17"I@&\x89\x8b\xccx<q\x95f\x02\xd8\x11c@[viH\x8c\xa6[m\xf8\xf9\x8d\xa2\xd1'
        b'\xde"\xfen\x8c+\x11gm\xda\xd8\xa6LM@\xa6\xda\xa0\xf9/\xcc2g\x07\x92?iv\x89c41d1k\x9f\x9a\xb1\x81\x9dD\rt\xea\xcc\xd2|w\xb0\niFJ\rQ\xbc\x83=Q\x7f\x82\xa1\xdaT'
        b'e\xa6\n\xa6\x0eg^\xd8\xf9\xf2\xea\x06\xa4\x98\xc2\xb0\xe8\x90\xe1u\xa9LTM\x9d\x05\x82\xd7\xc9)\x0cj8\x86\x8fW\x92\x8cb\xdc2ly\xa1\x9a\x82\x101\xdd\x87\x9fs\xc1V7c?\\{u\xb6\xc5N\x1d'
        b"\xf6\xcf\xb0~\xec\xf8\xd0\xb2c \xc9!\xeeK\xe1w\x7f\xde9.\x9c\xa2w\xc6\xf6\xa1\x02\xe8\x10'-4\xa4\\\x03\x1b(\xcd\xeeLbPc{\xe30\xaf\xa5\x16\x81\xca\x07\x0c8_-\xd6\xcc\xd7^\xa0G\xfaH"
        b"\x90\xc9\xa1M\xbfC\x89*U\xc9\xa6\x01e\x95L\x9f&\xf0U\x83\xcd\x99}l\xdfn\xb6\xdd3\xae\x1a\xc3\x8f\x0f\xd8\x80\x00\xd4rl@X*2\xeb\xf0\xf9\xff\xe4\x13\xe0\x914'\xd5\xc4\x9f\xee^\x96\x83Z L"
        b'\xa9\x9f\xb7\xe5\xe2\xc2B\x04 \xff\xfd)6\x12\xbb\xca0\x86\xce9=\x04m\x04\xcd\xf8\xdc\xf4\xcf\x87\xaa>hq\xf5\x04=\xf7\x98G@\xf2\xfe\x89z\xf2\x92\xda\xc5\xe7\xb0c\xfcz\xab\x0e\\\xf8i$\x1c\x8e\x02\xd3'
        b'\xf6m\x99\x8d\x83\xbc:\xba\x92\xc7"\xc6\xb9\xa9;\xb4\x87\xb9\xc4\xe3m\xb04\x1b\xf6\x85\xd473\x8dL\xf7\xea\xec\x02.\x82A\xe8\x97\xce\xb3\x87\xf0\xf9.\xd5Ii\xc5\xf0R\xdf9;\xd5\xd2\x10\xd2L\xa8Z\x07w'
        b'P\xee\xdb\xef=l\xb3\xc4Mb\x06\x8f\x10\xe1\x81|\xdc\xc6R*xVay\x8f\xd7\x86-\x13\xb9\x17\xde\xcd\xa7\xe6\x1f\x05\xc7]\xc0\xd6\xa4\x11\x1d\xc1\xa9\xb0}\xda4\xea\x06\x06gA\x00@\xbbY\xab]\xfa\xf6\xdf'
        b"\xa7\xf0\x7f\x11P\xd0\xf1\x91\xb0\xa1\xf2RT\xdbm\x05\x9a'\n\xdf\xbd]\xaf\xcd\x94]\xf5\x08dQ\xf7\x1ej\xf3O\xd2\xe6\xb5}?\xf8cz(\xb8\x95\xc8\xf84\xfd\xa3\xe8\x93\xa6\xdbd\xf4\xd9\x85-yd\x1e\xdc"
        b'\xa5`F\x00\x04f\xd1\x1e\x91R<\xf6U\xc6\x97:l\xea\xa0\xb3\xc5p\xf7\xd6\xaa\xea\xd5\x1b\xaf\x1d\xc2\x9al\xce\x95\x80,a\x14\xa7 e\xceq\x85\xf9\xf2\xf2\xd3\xf8\xd4\x1c\xcc\x1eUi\xf7\x8f3\x96Y\xc9\xb1\xe8'
        b'K\x94\xb4(\xf8\xd6\xcd\x83n[\x18\xed\xacT\x03Q\r5\xf1W\x8e\x00\xeahT\xd2[\xeb/\xd3\xe8"\xc4\xd0\x977\xc0*\x85\xd4\xd1\x06\x14\x9d\xfc\xdb\x9c\x8fY\xbc\xf5\xf4\xfa!7c-\xe5\xa1w\x7f=:\xcc'
        b'g\xb0\xce\x1b(F\\\x00\xe7\xcb\xd6@\xa6\xbb\xbd\xa6\xa1\x117\x00\x8c+\x18\xb8B\xa1\xfb\xdcL6\'\xa1\xa6\x8aZ\x05_U\xef\xe8\xc4\x0bY\xce\x15\xab\x9c*\x9a2I"\x8e-\xe6\x99\xd0]cq\x0b\xd9j\xf6'
        b'\x99/\x9eZ\xbd\xbe\xffT/\xb53\xbf\x16UM\x1cP\x8f\r\x8b\xae\xf5N\x19\xe2\xb6\xbf0]\xbdl\xca\x01\xa5\xbev\x0f\x91\x9b.\xb7\xe9\xe1KR\xe3*\xcc\xcf\xdfA\xb3\x9f\x810\x8a\xe9\x03\xcc\xd8%\xa9\xd1\x06'
        b'\xfd\xf3\x0cru\xa6\xc9\xa9R\x86\xf6ugO\xf2\x1c\xf94x\xdb\xc6\xc0\xb7\xfa#Q\x8b3\xae\xb0\xb0\xcf\x14\xb3\xd0-\x90j\x8c\x16\xa9bB?\x94\x94\xab\x9d\x7f\xca\xfb\x18\x12\xd2\xa8\xb7<\xcb\x93\xe0\x01u@u'
        b"H\xed\xf7\xde=K\x83/F\xb3\xe2\x13\xf1b$\x02\x19\x83\xe6\x81\xef[\xbb\xc2\r\xb9I\xf4\x1a\x82'\x85%\x87\xbe\x9fzE\xa1\xad\xe3E\x8bg\x900\xdf\xd8d\x9a\xd2w\x9d\xe2\xd7\xd8w\x1f\xd5<o{E\xaa"
        b'\xa3\\\xb8\xf3g\x06\x92\rp\xdf\x92\xadH\xe8\xcf\xba&\xf9\xb3%DR?\xc7\xf7p\xaeC\xc6Bj7\x16\xd3\xbc\x9eS]\xbdE\x04\xb1\x02(\xc0\x03\xa2\x10\x13\x9du;\xb1-hN\x84v\x17\xa0\xa4\xdb\xd3m'
        b'\xe6\xee\xe2\x99\xa9\xda\x81\xb2\xfa\xe7\xbbY2;\xd2\x87\xd1%\x928Y\r\x9e\xf8U]\x8f\x0b80\xdf\x07\xaf\xd6\x8d\xce\x01^\xb9n\x8a\xbb\xf1\x9f\xf5\x8b\xd5\xe1\xf8vZ\xfa\xea\xe8o\x0f\xac\xdc\xd0\xfe=M,]'
        b'\xd0\x8d\xea\x13uT\xe3b\xcb\xf6\x14\xa3\xab-\x98\xdf\x8c\xef\x11/\x16\xaf\xe25b\x1b\xf4\x9dL&"sP\x9c\x18\x10\x8e\xe3\x1e\xbab\x85\x9d\x94\x1c\xdc\x06\x1b\x86\x85\xb26\xde\x14\xd8H\xff\x87\x16|\x80\xa9\xae\x7f'
        b'\xd3]\\\xd5/CKp\xb3\xbd\xecf\xbf\xd4\x16\xe3\xb2\xe0]\xb1V\xd9\x9e\xc5\x12\xc4\xdc\x14\x11\xfe\x8d\x80L\xea\x12\xc7\x96\xf0!(\xfc\xc0\xc1 \x166@\x94\xa7\xca\xb1[\xc4\x1e_YJ\xe8n\xe8\x00\xfd3\xb3'
        b'\x99\xee@\xb1\x9c\x8c\xfd\xa63\xa0\x8anH\x86\x1c%\xde\x80\x81vq\xe6(@\xcehs\x00\xaa0\x9a/\x83\xc0a\x08\xf5\xed893\xa0\r\xf6IS\xb4\xd0@\\]r\xb4Il^\xcd\x1a[E\xea)\xe6\xa9'
        b'x\n\x99\xa7\xb0\x7f\x84[<\x99\x10vn`H^\xc2:\xcd\xd7R\xff\x06\xbe!\x96\xa6\xb71\xad+\xadY\xa7\x91)O8\x8c?\xfe\xcdM\x8d\xb2\x02"\xbf\x87\x04\x95\xc9\xa47\xdc\xe0\xab\xdb\x9b\xaaZ\xdaS\xe3'
        b'\x95\xa6\x11`\x16\x17\xb7h\x87\xc7zr$\xcb\x03:\x9d\x9dl\xce~\xe8TI\xefC|\x89%d, \xc3\x03X\x04\\\xfam\x8c\xa9e\xe2Lq\xf1\x9a\x1b\xdb~\x9c\xf2\xff\xdd\xb0\x9f\x03\x9c\xc5d\xc2u\xf4W'
        b"\xd9%?\xa1\xf1\x86@\xd8er\x88\xce98C\x1dW~\x1f\xd8\x91\x06\xc1\x8e[Xe+\xef\xb9'&\xe6\xc3R\x148\xd2L\xd5\xfb\x98?\x99\x7f2B\xf6\xff\xaeg\xcb\xd2f\x1a6\\\xd9Q\xfb\x0b++\x03"
        b"\xd9\xefpe\xb0\x81;,\xda\x87E$H\xeeVB'(\xc2/5\xa1C\xe3\xe5\x9d\xba3\xfe\xf2\xb6,\x92\x01\xed\x84\x127wF\x96\x1e\x05C5\x94~\\3\x81E\xf8\xa0%\xfc`\x9a7c8v6[\xd1"
        b'\x0c\xdf\xbb\xbc\xee\x02\xc2{rGu\x19\xf7\x95\xba\x1b%=\x06\x95\xb4x\xdcc\x19\xb0\x87.F\x93\x8eu\xba\x82\xc9$<\xcb\xef\xfd\xd7+\x1a\xeb\x0bM\xeaz\x82\xe2\xfb$K\xfe\xb3\xday\xcd\xff\x04\xb6\x97\xfev'
        b'\x19L\x02[=\xcf\x0c\x1b\t\xeb+\xcf\xabX\xdc_\xc6\x89\xda\x06c\x83!B\xd7\xeb\x12\xa9\xe8\xef\xdfL[\xbem\x19\xd7\x857\x89\x13\x8dbo\xde\xda\x11*\x95]od\x08\x10\x10~,\xbc\xb6\xa2\x1c*\x88>'
        b'i\xed?G\x89/\xd6\xbf\xf7\xcc\xe8\x9cRG\xfdY\x9fkmY\xb6\x9b\n\xc9\xb6T\x8d\xd7\xba\x9cm\x01\xfe\x93\t\xe4\xf57\x83\xefG\xec\xcek\xbd\x8a\xefb?\x14\xe4\xd3\xd5\xce\xa4V3"R\xdf6\xc5\xfe\x9d'
        b'1\x90\xf4\xce\xe7\x91\x9aF2\xf4\xe8{ty3\xe7\x9fa1T2\x1f\x0c\xca\xe8\xc9`T*\xbc\x92Q\xc2{\xa7\xa7:*c;\xce\xc2CZ{+E\x82\x03\xd3E\x8d\xdb\x146\xf2\x1b\x1dQ\x19\xeaE\xce#'
        b'\xe5\xf2\x97\xfaHPd\x1d\xc8&\x07\xac \x90\x82\x96,\xd6\x18\re-\xdb\x98\xdb\x84\x88I-t\x00\xb6\x92\x88\x86\x82&H\xfa\xbeUk\x1bl"\xac"\x02V\xf1\xe6a\xd4\x14\xc7\\\x8c\nfmj\xd4\xf6\x7f'
        b'\xfe\xb1\xe1:\\\x03q\x08\xb06x&84\xbc\x19f\xb9\x0e\xd9\xc1-\x00\xbe\x10aJ\xd2\xb2\xf3m\x85\xbcP\x93iq\xd6&\x972<\x9c@\xe1aa-Hm\xeb\xe9\xac/\xba8\x8aC\xa0s\xb1\x0e\xc6\xbe'
        b'f\xfd)\xb5\xb5[\xa8d{\xf7o\x91\x134\xc9Ma"I\x18Z\xff\xbc\x1d\x9dL\xa4\x86\x83\xa8\x90K\xfc\x9cF\x9bR\xc3\x99\xaf\x00h\x8e\x18\xab\xfc\xd4\x8e\x8c%\xb7\x16\xaf:@\xc4.\x98\xf7Aw\xc1\x94\xa4'
        b"\xb9#5\\4\x8e\xf2\x15\x0cR}\xc8\xc9\x95~/\x0b\x03\xf0\xc3\xda,Ey\x85II\xd0\xafT'\xe8\xcc\xc5Zm\xc7\x80\xd7\xbb\x89\xbb-\x06\x0c\xb7y\xed_fs!\xdb3?o\x12\xa64\xa0\xeb\x19\xc4\xa5"
        b'\x82\x12kH\x81\x14\xfd\xef]q\x80\x81\xe0pp"BG\xd9\xde\xc3\xc6}\x07\xc0\xc4\x1cD1\x8f\xb9\x0c\xae\x01:\x9bA\xc3+\xe6l\x14\xe7\'v\x1a\xf7/<S\xfd\xf3:r\x9d?e\x91d\rFi"y'
        b'\xdb\xe8\xcb\xce\x01\xc2K\x9f\xca\xf5E\xceQ~L9k)\xec\x8d\xaf\x01s\x8a\t\xb3\x8c\xcb2\xe2?\x91\xac\xac\x84tf\xee\x13\tB\xc9!(\x82\xf3 )\xbc\xfah\xd4\x19\xc14\xe1\xe3R>\xedW\xd9\x98\xfb'
        b'-\x86\xb6*\x1e\xca\xddG\x82:\x96\xd1=\xc3\x00(D\xa3T\xfa\x8d)u\xb8\xa1F\x1eUqh\xd0\xdc\xb1\xbe\xf6n\x9e\x05\x925O\xb2\xf4\x969\xd7\xa0\xd3{0\xfc:\x151\x1a<\x17\x85\x05\x1a\x06+\xe6\xa3'
        b"'\xb4\x8d\xc2\xa0\x022j\x01\xca\x91\x93a\x1a\xc9\x16\xfa\xc8\x8cu~$v\x8e\x08\x7f\x80\xedQ\x05\xfd\xec\xab\x1b\x8d\xbe\xf7\xc5@\xad\xe4\x99h\xc7\x98<c\xec\x0f\x141\xf3\xe3Nt\x9c\xf4\x93\x12\x87\xb0\xaf=\x8e"
        b'\xef\xe0\xb5\xbc\xfcDV9U\xb9,\x82\xbe\x94\xd8\xa2p\xcf\xb7u\xae[\x01\xe2\x91\x9d\xf1\xf3\x90-\x86\xe3V\x7f$\xb7\xdb\xc5\x9e\xb2\x1d\x1a\x83\xfc\x16\xe1\x13\x97\xf0r.\x9fOc\x9d\xf1\x95\xb5\xb6m\xe2?\xe9p'
        b'2b_y\x1d\x8d\xe2\xea\x18N\xd8\\\x83<\xbc/\x7f\xbb\xfb\xab\xe8\xec\xa2\xac\xa2\x01\x87\x91&\xdfZ>\x13\xac)yn\xca\xe8\x97Ki!Bm"\xd3+\xcc\xf4{!\xd5YRx\xd1\xa67\x98{x\x16\x11'
        b"\x85\xc7\xbb\xff\xa0Y\xbe.]#\xfd\x9cz\xe0RD'`\x16\xc2\xc8\x05T3&\xb0\xa12s%\xc5[\xca\xbb\xc1\xa6b\xf9\xaf\xea\xca\x13\x1d\xbb\x14\xe7HZ\r31]\xea!\x86]:\\\xec\xac\xbf\xeb\xd8|"
        b'z\xca]\x8c\x9e\xb4\xa2\x90p!V\xee|\xe2\x86\x81\x10\xa5\xa7\x902\xaa&\x18TN,\xe8}\xde=\xc4\xc6P\x7f*3\x04a[^\xed\x034\x0e\xbc\x17\xa7]3\x19\xce\xed\xc2\x0f\xeeO3\x03r\x98\xce\xf9\xf1'
        b'r\xbebg:\xcd\xd0\xb0u\xfe\x95\xd7Hw\xc3\xfc\x8b\xa7\xe5\xac\x8e\xa4h\n\x1e\x0fm\xcfU\x81\xc3\xb3>\xec\xd3$S\x05\x8coi@*\xba \xc4o\xb2m\xbeV\x8cBG@\x0f]WJK\x12\x02\xde\xac'
        b"\x029uf[<\xa7\xd41\x83\x97'\xc5\x8b\x05w}+\x9eR\x15\x7f\x9d7)\xeb!\x95](.L~\xed\xe1j\xae\xa28\x90\xa0\xf1y\xa3\n\x95\xc4\xa9\xc0\xd8\x05^\x1as2\xacX-\xc5\xd7\xaa\xff\x82\t"
        b'\xc9\xb0\x82\xa0L$\xcb\xcf\x0b\xb1Q>$\x1d\x91\x0bA\xfd\x04\xff\xc5\xa3\xb6\xa4\xd0oj\xc2\xe4\xd6\xf6\x7f:\xd6p\xe0n\x8b\x81\xbf\xee!\xdd\xd6\xf8\xef\xc0i\x87\xdf\xaa0\xfd\xe6\xa6l\xe1\xb8\x9b\xb3\xb7\x8b\xc52'
        b"\xa2\xf8\xa7\x97\x8c\x1b'%\xb7\xcd&\xc4\x97\xa7\xec\xeaA\x14P\xbb@k~b<l\xc1j\xe7\x1d\xc2\xa2R\x04`P\xc9\xca\x1c_\xff\xfe\x80\x0e\x0b\x91\x990\x9dC\x85\x1e\x86\xa5\x9b\x0b\xfb+\x12\xb1m\xcau\xb2"
        b'e\xf7\xa7j"\xa2\xff\xfc\x06qU\xb3\xa8pXb\x95\x13\xa8&[\x8dqarc\xcd\x87\xba\x0b\xfd\xeb9m\xdc\xbc4"9\xfe\xb5\xcf\x87YL\xf1\xd7p\xb9\xa6\xfd\x94H\x99\xf8q}$z\xfa\xc1\x91s\x81'
        b"[\xe0h/\xe0l\x98\xb1|\x9fC')\x18\x0e\xfa9R\xdaT=q\x06f\xb9\x16;\x0b\x19\xa1\xaag\xd9\x19\xd7\xca\xbe\xc3\xd9tT{\xe6gdG\xd5k\xb5-\xd8\xe1C\xf0h\x8e\xaf/\xceH\x80\xa1\xb6D"
        b'n\xa1hh\xca\xba\x0f\x88GRc,7D\xbf6\xf6*\xd4\x18M\xa7R\x8d\xaa\x03\xd0\x10\x89\x06Db8\x951\x0b\xb3O\x1f\x07\x98\xb2\xfb\x91ev>\x12F\x92\xdc;>\x00\x9crp{\x1b\x8cO\xc9i\xa6'
        b"Y\xb9\xe2\x18\xb6\x8d\x93\x04\x9f\xf8\x1e\x7f-\x0e*65kx\xc6\xddI\xd8\xed\x9d\xef\x836\xf0\xd5\x8a\x0e\xa6\xe7\x98\xd6\xd6\xac\xb3\xe6[|-\x86+4\x93U'Q\x83\x08\xcfY\xcc\xda\x86Em\xff\x10,\xf9\x97"
        b"\x16X\xdd\xcc\x96\xfa\xa4\x19\x07\xfb\x18M\xe0;\xb1g\xa9\xfe{\xd3\x97\xdd\xf4\xbb\x940p {~\x91\x01\xd6-\x05['\xb5\xd5u\xf3\xcd\x85\xa8.\xfe6G\xf6\xdb\x1c\x1c\x1e\x97w\xde\xdd\xfd\xba,Q\x1eV9"
        b'X\xcdM}\xda\xaf?>M\t@g`\xc7q\xec\xde\x9f9\xc3\x1a\x19j\xbf\x134}i \xe61\xd9\x82t\xa6}\x80\xdf\x80\x0e\xad\x85\x07\x02\xf6\xb970\x1c\x12T\xa6l@X"\x84U\xc9\x04m\xcb\r\xb0'
        b'\x9d\x19(`\x1a~ \x9c\x04\xc3f)\x18@\x10\x93\x11\x074Yu[c\\\xaf{\xaf\xc4\xf6\xd0\x9e\xfa\x8dC\xa9\x18+\x90\x0fs\x86\xab3\xe9\xd221\xfa-\xb2G\xa0PW{\x84\x1fy\xa5\xf5\x82\xfa\x89\xc2'
        b'=w\xcf\xbc\xfam\x9c:\xa3/d\xfeh\xf1\xea-\xb0t\rl\x05\xf5\xc18\xbdz\xa0\xf8@\xa1\x97jB\xf9\x9blc\xea\xbe\xd4#\xaf\xee\xa5\xbb\x92\x19\x9a\xdd\x01I\xdf:[\xad\x8e\x88\xdf\xa9\x02?\xe9\xa6('
        b'n^\xfay>\x81D\x9e\xa6f\xf7\xd9\x7f\xe1\xb2G\xf6\x9e\xf9\x1f\xe1\xd8g\xf1\xbc\x80N\x85\xc6\xc7d\x14\x87\x9ak\x07\x1c\x9aVK\xe8ut\xc5\x99\x84\xc4\xe1\xa7\x14\x9au\x7f\x8b\x18\xd0\x18\x0e\xc8\xa0\xf6\x94\xe7\t'
        b'C\x10\xfb\xc90\xa01I\\\xe26tW\x95%\xcaV\xb0\x99\xbc\x9a\x8bX\xba5\x8f\t\xfb\xc0\x9e\x89M\x02\xe0\x00\x9b\xd6\xfa=\x0bpW\x98\xf3\x1b?\xaf4O\x8d\x7f{\x15\xfd}\xfe\xe4$B\x99\xc1\xed\xe7\xa1'
        b'\xa4\xc5[\xbf~\xaau\'\xa0\xb8<\x80R\n\x94u\x06\xc2\xc47\xc8\xa1\x93`\x1a\n\xd2n\xb3|\x14\xb9\xc5!\xa1\xf9\xd9\xb7\xa2\xd2K\xddG\x02F\x13y\xcf">\xfe\x03\xf7\x0b\x08\x93/\xeb\x0f\'\xd9\xe06\x89'
        b'v\x0cW\xb1)\x8a,\x95J\xb6\\\xf5>\xb7\xdb\x00\xde\x9eYN\\U\x96T}\x8fGV"\x19\x8eqg\x93\xca\x00\xda\xe4\x1d@\xae\xfa\'\xaa\xb0KI\xa6\xb6)\x12\xf4m\xe3k\xedX\x05\x86\xb3y\xcdV='
        b'\xa3\xc0\x16\xecCe\x1aL+\x1c[Oo\xbe\x10OVu\x1fIW\x08\x07\xe1\xa5\xf2\x96\x99\x84\x16\x92\xb9\x9bYO\xbcX\x7f\x19\xe8l\x98ks\rZ[>\x85\x1c\xebl\xc8OOB\xcaa\xd8\xe5\x1a\x07\xa4\x18'
        b'\x1d\x12``\xbe\xca a\x1e\x86\x0e\xa2;V\x15\xb9B\xf2\x96b\xa2\x13\\\xd07\xbd5~\xf3\xde\xf0\x12\xef\xbal\x9fcdw\xf6\x07I\n\xd5\xae|k\xe3\x81\x9a\xfa\xbd\x92\xb2\xceO\x88\xb8\x8e\xe7c\x1f\x19<'
        b'}\xfe\x19\xbao!\xec\x9e\xc8T\xcc!+3\xce\xe8\xfd&\x93k?d\xd1h\xac\xdd\xe9\xce\xc0s\x1a\xa0\xa5\xdcf|Q\x8c\xd3\xc9\xb9\x0c\xc1\x8f\x95\x0b/!_12\xcd\xfes[S\x99cL\xb1\x06\xd8\xdd\x1c'
        b'@\x00N\x9a\x9e\x15\xcc6\xd19V\xb5\xcc"\x0bRl\xec-/QS\xd2\x8bw\xeb$Z\x16\xc399\x9d\xacnm\xf5rW\x7fY\xf8Q\xf4T\x85LC\xe5.\x9b\xe3\xda\x06L\xd9\xf9m\x94\xfa$\xbd\x05V'
        b'\xd4\xa1\x89\xb3m\xfe\xe1 \r\xde\xaa\xd3\x89j+\xdb*\xa2\xe4t\x8a\xbf\xd53\xdbJQm\x05\xf7\xeaA\xdf\xd2\xc1\xc8\xc3"\x80s\xcd\xb2\xb7"%\x83\xb7\r\x84\xc6\xca\xf9\x9aM6\\\x16\x1d\x0f%\xafh\xef`'
        b'\xa829K*(7\x9d\xe6?\x8c\x0e\xf1\xf2iO\xc2(\x86\xc6\x1c\xda\x97lBj\xbc\xde\x8d\x8ds\x05\x13\xc9\xb6\xcb\x89\x12lrJ7\xa9\nQ\xb7x\xf5\x8fg\x97\xc2K\xcbrkh,\xb0\xa0O@\xb0\x1b'
        b"\xdb\xedHQ{w\xa3D\xe3HD\x9c\x99\x84G\x87\xf0\xd8\x82\x02v'{\xe1\x8f\xfa\x14\xe6\x08\xb4\xacr\xad\xf1\x88\x010\xf5#;#\xe6Z\xc9\xd8TV\xfa\xf7e\x10V\x8d\xb7\xfb\xac\x9c(\xb0\xb7\xc9\xb85\x81"
        b'\xe6\xbf\xb0\x81\xbe\xc7Xv\x12H\x90\xf6\x89\xb7a\x07\t\xf4\xecSC\x83\xfa\xf3\x9c+\xfe\x02\xdbG<\xd7\xc7\xd0h"\x84#t\x8f\xe9\xf6\x93}\xd4\x07\xbd\x0f=\xb5U\xa5)\xc3Q?\x1f\xd4\x96p\xbb\xcf\xda\x9e'
        b'\xb8r^C\x8a\x8b\xc4yGl$\x95\xa9y\xbb \xaa\x03o\xb6d\xfa\xe0\x19;\x8c\xf7P\x87\xe3\xbb\xae\x7f\x98\xef\xaf\xac\xfa\xf4\x19\x02\xae\xec\xc1\x10/\x1dp=\x9f\x0fWZ\xa5K\xc6f\x8d|c\x1b\xfe\x95{'
        b"\x1b/\x87\xd7\x17\xea\xaa6\x1a\xd5\xd6\x82\x1c\xf4\xe7\x9d0\xdfp\xe7h\x86\x0b\xc5E\xa9\xcb#'\xb7\x9a\xed|\xb8_HI8@>\x93\x84paP<\xd9\xa6\x10\x8d#\xc9@\xe5rq\x14`\xbdU\xe3\x8f\x7f\x9c"
        b'\xa2\xe1j\x11\xf1\xdc\xfd\xac\xd1\xea\x86\xa1\xce\xc6\x1df\xf0\x84\x07\x96C1<\x11NaI$\x13\x0e\x91X\x9cR&\xf1\x90\xed^o\xf4\xe3\x12\xe0d\xffIn\x0eQ\xe3^h\x9bp\xe7\xc6F\x1br\xdd\xa0fl'
        b'\xe0;\x8c@\xfa\xc7\xe8\xcai\xa0\x01B_}\xc6J6\x87\xd6-\xe5\xed_\x01H\xbf\x07i\x03\xf0z\xd2\x97H\xe2\x15\xe87\xf3F\xda\xea\x16\xab\x1c\xf7\xeb\xe8\xd5~\x9a\xcd{;!\xbdY\xafi\xd2\xbbn\x1a['
        b'\x8bI\xb4\xc8F7\x84\xdd\x9b?\x99\x1f)\xc4\xc4\xd57\xd1xe8\xd2\x05\xec_!\xfb\x19\x18p\x15^\x9b\xf9z\x04\xea\x8d\x95\x85\x8d\xa0\x15B\xf8\xff+\x11\xe5qF\x95\x06\xf7rP\xd4\xb4n\xcdU\xf7d?'
        b'^\x8b\x8a\xb7\x95\x00\xb8\xaa3{X\xd9\xd2\xd4\xe5\xde=\xeet\x9f\x97/\xe8\xf2\xf0\x01\x8c\\\x96\x1e\x87\xf0[R6\xf4{\xf0)\x15\x9e\xcc\xd3\x85\x8c\xb7l\xb5\x93\xf7\xffA\x1c\xfa\xea\xcdXA\xaa\xe8\xcd\xe8\xec\xff'
        b'\x92b\r\xb5\xfc\x1f\xe5c\xacp\x80{\xa6\x1bEUA)\xb9\x91\x8e\x93\xeb\x1a\xa0V\xf5Z\x08\xa8bQ\xe5\xdb\x0e0I\xa8\xcb\x1a\xfa\xd4A\x8f\xe1\x01\xbf]\x85T\xd5\xe5b\x10mQ\xc6\x9c\x18<\xe1\xa8\xf6|'
        b'Ex"h\xacLu\x10O\xee\xd7\xc2\xcf\xf7r\xe6\xd6\xe6\x9b\xe0\xc4 `6\xd9\xbcV\xc6\xcd\xe0\xd3D\xb3\x9cK\x94\xa3\xadR\x11\xa1v 6\x8ew\x84\xa4,Ly[\xb1\xcf\xd1s\xe8\x05\xa2\x1b\xc0UT\xd6'
        b'I\xbd\xae\xd8\x90U;\xae\x99\xc4y\n\x8ai\t\xb7\xbe\xa5\xaf\x11\x1a\r\xe2\x19"\xc5\x0c\xff\x8d:\'}\xff>\xc6\x99\xff!w\xb11\x8cM\xb0\x8d\x83\x06\xd5\xc3\x83\xa2\x82\x81\xe9\x19\xbd\xae$2/\xe6\xa6,\xe0'
        b'\xc3,v\xdd\xdb\xdf\xd2\xb8D\x98\x9e\xbe\xb6\x87\x99\x9d+h\x1aU\xf0\x0c\xcb\x01\xa3\xeb\x1fMc\xea\xcb\xdc\xb4\x04\xbe\x95\xd5\x07\x1c\x91E\xe5b\x14\xb0h\x8f\xb0D\x87;\x1b^\xfb\x10?\xc7\xca\x07\xcc\x9c\xab\xe2Q'
        b'\xed\xde\x13h\x17,\xda\xa3T\x19F\xd2\xf9Q$\xe5\x0c\x19\x1cyI\x8b6C\xf7\xf0\x7f\x0f\x1d\x98\x1b\x95\xdc\xc8Y:\xab\xde\xd0\x11r\x85\x0cN+\x02\xa1\xf1N\xffVj\xce\x86\xb9\xb3"}x\xb5\n\xd8+o'
        b';}Lp\xc1X\xab\xb9\xf5\xa6\x97\x8f\xde\x7f{\t\x17y\xb1\xce^\xfc,\xf3\x88|\xb0\xbb\xf7w\xcd<\x1c\xda\x13\x88b\xd0$w\xaeb\x16 \xca?\x8c\xa1\xd3>O\xac\xd2)\xde\x93\xbby\xb8\xe0\xc92\x18\x80'
        b']-\x9aB\xd0\x10%&#98\xcf-\x1c#\xf2\x1a_\x80bc\x8c\xda\xa5q\x92\xe7\xc7\xf3\xea\x94\x13~.\xac\x08\xa8\x1c9}\x9c\xf0\xe2\x8dJx`\xb3\xed\xd36\xf0\x86ZK\x8drq\x96\xde\x96\xb1\xc5\x8d'
        b"\xcc\xea,5X\xf6\xf3q\x7fD\x9b\xbc\xea\x9e\xff\xaa\xff\xf6\xea\x13\x80\x8ej\xbf\x7f\xec\xb6)\xb9K\\\x05\xd0\x035qv\x91\r\xc6\xbcKq'\x81\x84\x92lc\xee/\xb6\x11B\xe3\xbdf\xfb\xb9\xb0\x01~A\x9d"
        b'-lQ\x95N\xccN\xbd\xbbo\x94\xca\x8aKx\x1c.\xd8\x1f4?\xe2va\xc1\xfdJ\xf4\x99\xd5S\xa3\xde\xbd\x98\t5F\xa5s\xe8\xafcJ\xf9\xf3X\xaf\x1a\x90F\x8a\xcaC\x87V\x80\x92\xd1\xdf5\xa6\xe0p'
        b'\x08\x8a\n\xd6:\n\x8b\x18\x0f\xe7\x0ch\xc3D\xc6#$5H\x1d$\x93*W.8\xfc\x92\xfc\xd2\x04b%\x7f\xbd,\xd3\xbb\xb3\nhY\xdaD\x15\xd0E\xc8\xf9p\x03\xdf4\xe9\xd5\xf5\xa3{\xb1\xf7\xe2\x83Y\xb4'
        b'P{\xaf\x8b\x8dW\x1d<\xc5h2n\xc4\x9d&u\xcf\xb5\xd6\x86\xe3\x07[\x89yz\xf2`*\x17\x0b\xe3Y\xc7%d\xf8;\n\xde\xa7\xf9\xb8\xbb\xca\x94\x92\xe5\xc3\xc1\xe4\x13\x98\xb0-\xadN\xc0\xfc4\x1cO\x8c\\'
        b"\x8f\xad'n\xf2B\xa4\xaf\x8d\xe9\xb3\x8df?\x00\x95A\x06\xbd\xd1\xb3\xe5``\x16\xdcF\xd11\xb6\xfb5D\x95\x83\xf8\xf1\x1dV+\x9f\xc4P}\xec\xc7d\x19\xb7\x9b\x05\x1ct\xb2\xc1_\x08\xaa\xb6_j\xcf\xa0]"
        b'P\xd4\xcb\xcc\xa5^\xe4\x8fa\xc0\xf1\xaf\x8dK\xf8ym\xb0\x89\x03\x80=\xf3!\x1d\x1a\x05\x93\xe7\x0c\x89r\xdfD\x80N\xd3\x90# Sm\xfe!#\xe8\xc6 L\xb2o\xe7I\x82\xd1\xa6H\xff\xa3\x8a)\x05!\xb7'
        b"\xc67s;\xafh\xa6z?\xe3\x81^\xe6\xcd\xac\xc97iv\xa4*2\x95\xfeR\x0cN\x96\xfe\x14\x8c\xb0\xd3\x92)x\x94)\xeaf'\xc3\x97\xf9Q\x1f\xfa\x9c|\xe7\x01'5\xa0\x8f\r\x8a\xda.X\x88\xfc\x8e\x9e"
        b'\x8bR_P\xbeH\x18\xab\x91\xe1d\x9c\xac\x01\x1ao\x04\xc7l\xe5V\\\xea\x88\xfd\x1aw\x89\xf6\x97f\x853\xf6\x96S\x8axuc[,\xb6\xa5\xa8l\xd5\xcaK\xf7Y\\\xb4\xa7\xf7/%U\xb2\xa7{\xb1\x10\xa1'
        b"\xe1'\x0b]\xc2\xf5\xd5\x12\xe5\xa8\x9c\xf8\xffb\xf6\xb9\xc5\x06\x0c)2\xef\x1d\x83w\xfb\x7f\x1a@\x9c\xe0\xab\x18\xf1P\x8d\xa7\xc1\x84N\x9a\x0b\xf9E\x96\x85\xb0\xb0\xc5\xa7\xd4jP`\x8b\xa1,\xfc\xda\x84\xbc\xe6*p"
        b'C\xd0\x90l$\xd8 :\xbc\xe0\xebP\x1a.:m.\xb6\xce\xd9\x94r\x94\x8d!~n\xad\xd6Y0\x98\xed\x04wZ!\x7fI\x19\xc3\xf5\xf9Mk/\xf7\xed\x0f\xf2\xa3\xd4\xa22\xac!\x04`\xe1R\xd7\xd0\x8eY'
        b'\xc4\x14\xdb\xa6\xa9\x91\xda;\n,\xe9n\x0c\xfa=\x01\x1f\x999\xc4.\xa9Km\xb9Vu\x10\x9a\xdd\x834\x92j(n;\xdb\xf3\xc0hb1@16\x06\xe8`\xf2\x855\x80\xde\xd1T\xcf\xb8h\xc5[\x80\x95;'
        b"\xac\xf9\xfa';\xa7Id\xfaM\x1a\xda\xbf\x05\xb7\xcdD\xecA.\xbf\xe7\xdfX\xd3z\xd9w\x89X\x18\x82\x93\x1e\x1c\xcc\x8aS\x96\xf1\xeeW\x98\x83i\xf7\xac\x94Z\x10TT\xdfk\xd7\xe9\\\x7fy\xd0\xf7\xe0i\xf7"
        b'\x14!\xdasb8A\x00\x1e\xe9\xe8\xfc8\xfa\xb9~\xbd\x92\xcel\xf3x\xa4\x17\xb0\xb0+9\xb0\x04&\xf0\xe6\x98\xc6\x88\xd7\xc9\xc9dI\x9b\xfdX\x83\xdc\xcd\xa6\xd1f\xbb^\xd5l#\xd3\xb8;Mo\x11\x01\xe2{'
        b'\xfa\x9e\xd4d\x95\xc6_\x90\xb2\xe2\x10\xde\x96\x19\x84\xd5\xde\xb1\xcf\x17\xf3\xf0\x97\xbe\xde\xa9(\xe0\x9d\xc7\x8fV\x04\xe3\xf1\x13L2!h\x97\xe1\x13\xbfX\xbbb\xd71J2+:-eKz;\xd7C=\xd0\xcdn'
        b'\xaf\x98\x8e\xb0\xeb*I\xe7\x16\xb6\xbb{\xc1\xca 3\xb1\x022\xf7\xc8z\x95\x9ecl\xaf\xb5\xb7\x83\xc3\xf7:\xe57\xbc\x06N\x80\xe1\xcd1Sg\xd8\xaf\xd4\xe2\x0e6\x88\xc1Ox\xbe\x06\x85\x0e\x9c\xb5y \x90\xc7'
        b'\x05\xc4\x10\x01d\xbdx\x8a?8e\xa7\xdex/NT\xf8\xe6\xcc\x91\x99p\xa1~\xd1/\xf9\x8d\xe5\xe76\xe4Y\x95vd\x07\x12m\xbdVQ\x89?i\xd9\xe3\x8a\xd6\xd2\x07U\x93\xa7z]/"1\xff\xd0d\xac'
        b'\xdb\x1cC\xea\xb8\x93;E\x01\x94t\xc0J\x016\x01\xa2\xc4|\xae~-\x10S{N Uq\x9d\x92\xdf8\x92E\xc0\xb6\xbf\x13fk\x13\xe0\xac\xd0C\xf6\xa8\x8b%\x03\xb0\x9aP\x12\xfd\xf2K\xc0\xa8\x00F\x01W'
        b'\xdd\x1aD/,\xc0\xb4/\xf55\x8bnF\xdf\xb1/\x15\xbe|&.^\x95\xf0\xeeOk\xf3\xbb\xef\x9a\xb2q\x89\xcd+X\xd6\xee;\xc6\x1d\xcf8\x8e_g<\xff\xa5\xbe\xf2_H\xaa\xbe\xdd7\xae\x96\xcb\xb9\xe8~'
        b'Z\xdeL\xe2\xd3\x8b\xba&mA\xe9\x14\xcde\xcb\x82+w\xd96\xc4\x08\xd6]V\xda\x0cB\xa6\xfe\x1b\x17q\xd0\xe7{9\xa6-E\x1a\xde\x7f\rv\x1dj\xc6&\xf0\xa0\xd9\xe7n\xbf\x0f\xf4\xd7\xf7\xab\xf89W\xd4'
        b'\x15\x16\xe3\xc6\xdb\xaa\x7fF\xafO\xdc+\xc4\xc0&j<\x18Z&\xa9\x0c9\xc3\x18\x93\xc0\xdaDR(\x93;\xe3\x99H\x16\xbc\xcd\xa7\x93\x8ba\xea\n\x8b\xbf\xc3\xe56\xff\x9f\x02U$\x18\x9f\x7fqn\x7f\x0e\xb2\xb1'
        b"0\x93\xb5\xd4\xc5\xc0\x9d\xd1\x9b=\x99\x87\x9a_h\x8e\x07O\x9f\xaeE\xc4\x15\x15\x80<\x12S|\x83x\xf7\xa9\x00\xb4W\x97\xf6L\xbe\xea\xb7\x8a\x8b\xc6\xea\xc28\x15\xe6~\x19so74G\xb2\xb9\xce'y\xcf:"
        b'\xd11\x89Z\x97\xac\xa8Xx\xff{E\x0c\xf9l3\x02\xcb\xba\xaaE{R\xfe\x1c\xed\xa4\x89[W\xaa\xa9c\xc4\xf2P\xbe.@\xad\xe8\xc8m\x10Wx\xc7\x12l2\xb9nPJ\x03fY\xc9\x12Yi\x82\xa5:'
        b'N\xa0\xf9\xcd\xfeQ\xd4=EM\xc9(^\x19\xc3\xcd0\xa2\x18~\xae\x8b\xcc\xc0TAzZ]\xceQ\x04\x83c\xef\x9eU,\x9aJl\xf08+\x1d\x95\x89\x0c_\x0c\xc5\x08\x00\xc3\x93:\x89\x94*sF\x93y\\'
        b'\xe2G\xab\xa2(\x8cI\xb9\xa3\xe17\xc9\x1f~>\x08\xff\xfbE\x8c\xd0\x93\x7f\xb0\x95L(\xd6\x07\xdb`:L\x9f\x03\xbc\xb2j8]\x05\xa0YS\x9d_\xacw0\xfd4$\x82q\xac\xe0\xf0\xfb\x18\xfbb\xa1\x0f\xa6'
        b'\xd2\xcc4\xb2~E\xb8\xb9\x0b\x10\x82\xce[\xc2.\x117\x16\xd8y\xacz\xf0t\x9f\xf8mj\xbb/\xb1\xe1L\xbc(\x83^S\xa9\xe0\x1a\x11\x03\x1d\xbf`\x1b\xbc\xc7\xf6\\\xdc\xb7+\xf6,a\x01\xc7\x04\x1b\xb6\xdb\xda'
        b'~k\x99\\+2\xe9\xe7u\xef\xe7^h#\xa9\xd0\xdb\xf3\x08\xcc\xc0,\xdb\x1016\xa4\xf7\xf7\xf23H\x15\x95\x85\xe0\x93\x98s\xf26\xe9\xf8\xcd\x0c\xca\xba\xdd\x1b\x05\xc2\x91I\x9d*[\xa9tHY\xcdU\x90\xab'
        b'+l\x18-\xdct\xef\x92IB6kbEE\xef\xa8mn\x99\x0b\xf7\xe2_\xfdq)\xe5\x04g0\xb8<Ap\xf7\x96\x13\x8b!\xdd\x02#\xf3[s\x05\xf7\x8a\x1b\xac{\x0b\x0c\xe9p\xaa!\xf8\xbf\xaf\x16\x15\xc8'
        b',\x9bgv\xe64@3h,O\xce\x9fBv\x08\x89\x19.qz\x0f\xf6\x8c\xa3\x7f\x93Q\x08\x06=\xb0\xe0\xb0\xf4\x8f\xf7\xaf\xcas;\xea\x86\x11\xa2\x06\xd15\xfav\xab\x93o\x83\xdb4A\x97\xd6F\xc7K\t\xba'
        b"\xb6\n\x9a<rk\x17uS\xa3CW\xec\x17\xbd\x16MG\x079\x8c\x15dB\xb8\x98s\x02T\x0f\x83Mw\xa3\x01\xa1{\xda\x8d\xfd\xbfN\xeb\n7'z\xd3\xa9\r\x19\xe3v\xc8\xfe\x80\x89\x1d\xfd\xadEL\xcb\x1a"
        b"\xab+Y\xab|\x10\xee\xc9:a\x8b\xa69t 2\xefqJ\x0c\x11\xbf8na\xa0\xc5n.\xfc\xc0\xa7\xdf\x9a\xca\xe8\xbb\xa5\x1f\x1dZ\xe3\xf1\xf8$\xae\xa63'S\xf4\xd9\xf4\r\x91\x93\x89:\x84\x94\xbb\x1d\x19\xdf"
        b'z\xee\xae**Q9\xa72/\xb17\x9ae\xb2}\xd2\xd2\x91\x8a\xba\xc3\xd2\xdb2\x9c\xd01][n\xa8\xbey,\x97g\x10\xbd\xac\xf6\x07m\x13&\xe85g\x0e\x10\xf3\xc9s\xae[,\t\xb0"\xe3,\xe6\x86\xae'
        b'\x83\xa5w8\xd4\xc4\xfa\xc1\xc7\xb8\xbdf\x05\xce\xd6\xe0H8\xaf\x19^gX\x12=@\xdfF\xf4~N\x13p{\xfa\xc1\x1fu\x10\x9e\xc7\xd5\x9bFd\x82]:0\x9a\x070)6?\x12k\x7f\xd9\xbd/)i\xdc'
        b"[Z5.;\xb2\x01\xfc\x9b)|7\xf7S\xa2\xb6\x05C\xf8)\xbb4?\xa9\x98\x8a\xc1\xac\xd5\x89\xe2}xV\xe04\xcc\x12\xcd \xbf\xeb\xed\xcakD\xa5\xedF\xafR&\x91\xc7V'\x9dsm\xaf]\xfb\xe2@"
        b'\xebX\xa21\xf2:T\x12q\xc6\xd3[0\xa8\xa8\x10}k\xf0\x17\xad\xf83 U\xe9/\xc7b\xc5R\x0c\x1c\xff\xcb\xed\xaaC\xc9,\xa14\xde\xd3G \x87\xf5\x9f\x88\xe4"\x87\x90[^Y\r\x83\xf8~\x82\xffD'
        b')/\xb7%\x98\xe4o\x03\xf1\xc7\xe5>\x03\xfej\xd7\x88\x15\xa1*>:\x97A\x14\n\xaa\x05\x8b\xb7\x1e\xd0r9\x02\xc9|\xfe$c\xb7\x91\x8f\xa0\r<\xdf9H\x11\x10{\x01u\x159^\xb9\xfe=\xc8\xbe\xc2l'
        b"\xdf\xfby\xd8'\x9eV\xb4\xfbX\x8f\xc6mN\x91$\\\x97\x1c\xad\xd4\xd2\xc8\xb6\x9d\xd5\x07q\xba\x83BX\t\xc922\xc2\x16\x80\xae\xc0\xe4R\x0c\xc4E\xe2\xd1H\xd7\x93\xf2\xfe\x01\x93*\x9b\x89O\x90*\x8c^\xce"
        b'j K\xb6\x80/\x9c?B\xfd4~\x9e/\xa6\x86Y\xa0 \xc8\x7fe&\x7f\x18\x8b\xe3\x16\xd3\xf6NVu\xd0QB\xb41M\xa6\xf9k\xfe\x82\xfa\xc1\x93\xef\x14\x00\x1e\xbe\x05\x16P\xa3\xd8\x19\xfb!q\xd4\x96\xb3'
        b'\xa1\xfb\x08\x82\xa2\'{\xcb\xa3t\xef\x87\n\\\x8c\xaf7D\x9c"<Q+\xf5\xd2\x85\x04\xb9\xb2w\xe8\xf0\x08\x12\xb8\x85V\x82\xd69g\xf8\x8f\xe4\xba\'LG\r(\xe6\xd5\xbe\x0c\x0e\x1c\xd3\x1d\xa9l1~\xd1\xc2'
        b'b#/[\xf1.\xea\x04\x02\x19\xa6B\xdf6\xb8\x1cB\x14\t\x9b\xe2\x12\xad\xad/\xbd\xc7d\x91\x8cc\xfd\xd3\xa2\x12$\x1d:\xe4\xca\x13\x81M\xb8Vd \x91)\xc8\xb7X/\xd5\xe4rt\x8d\xb37MRak'
        b'\xb0V\x8e\xdb:\x98\x15\x91\xc4\xe5q\xeboF|\xd8\xac\x12>\x06=j\xd7y(\x1f\x81\xa6LZ_\xd3.\xe0t:<u\x1e\x1c\xe5\x8aQ\x1f\xc9\x8bC27\xa8\xc1\x03\x1d\xb2h#\x8d\xe1\x8d\xe3\xbeK\x99\x9d'
        b'\xe0t\xac\x80\x88\xa5\x9b\xd5\xefG?\xc8\xe9\xd4\x9c\xb1\x96\xe7\x9e\x0b\xacn\xe1\xa0yt\xe09oE\x14+]\x90\xa1\xbe\xed\xe7\xcd\xef\xbf\xc5\x80\x87\x0f2^\xa9\x18\t\xd7\x98\xea\x0b\x88z\xc1\xbe\xb7\xca\xd8M\xe0\xca'
        b'\xc6\n\xc7\xc3g\x8c\xc9\xa0\xe1w\xc8\x9c\xd0\x8e6\xb2%\x8aJ\x8f\x8fc\x9b\xe0\x0ca\x11\xdc\xa1\\O%\xe5\xa1o\xa4\x02@\xe2\xa9\n\xc4\x8d\x8f\xab\xebX\xe1\x82P\xdb\x19\xd40\xe1j\xb9\xc3P\\C\xfa\xb3\x97'
        b"\x9a\xc6S<WE\xc5m\x1e'n5\x1bag\xb5IMwp \x978\x195\xe7\xa0l\xec\xb6\xb2%Q~\x0b\x84[\x9d8\xc0\xce\xa2\xb4\x7f\xfd\xbd\xd9\x17\xd3\xae\x00\x93\x1b\x9f\x9a\xe7\xef\xce\xb8\xe8\x17\x1f\x8b\x8e"
        b'\xe3\xc2\xe3@\x17\x0e\x1fo\xd4\x94\x95+\x96\xf8\xf0[j\xaf(Bge2\x1c\xa28\xdaig,\x1d\xb7v<\x86\xe4\xdd\xee\xe7\x13" \xb70m\x9a\xffV@%\xa4Er\xb3W\x00\x89\x85\xe6N\x19c\xe0\x99'
        b'\x9f\xac\x80\xab\x96\xc1\xb1\xa5\x19\x03\xdc\xe6\xe1I\x14\xdb\n>l\x8b\xd6\xb1uV\xd9\xe4\xd6\xd1Y\n1|\\\xcb\xaf\x8a\xe1\xd1\xde\x11q\xeb[\xde-\xdb!\xf5\xd0\xfa\xbd#\xfaux31\xcbF\xf4]\xe2\x12B'
        b'\x0c\xc8\xc3\xeb\xd9\xc18A=\x8a\x83\x19\xb0\xe5\xffF\xed\xb4\xd2\xdc\xcc\xaa\xd0;P\xd1&$\x00\\\x08\xb1\x8d\xe5\x9e%v\x93`\x92#\x1e\xb5\xb5b\xf8\xfd\x95\xd8K\xe6B\xb3Iw\x83N\x81r\x8bE\xe10\x80'
        b'\xcd?*\x01\xe4\x8fW\x0b\x0e\xbf\xff\x0b\xf5Y\x0f3\xa1\xf2\xb6\x97yaO\xe9\xb8*\xe5\xa0\x8e\t\xc0\xa6\xa7\xafdL\xc9n\xb7BIV\xc1\x06\x15\x8c\x11\x05~\xe2K-\x05\xa8\x87\xd2\x99\x18\xbeI\x1c\x08E\x85'
        b'\x0e\xeep;\xb6u7\xd1:\x84\x8f\x95\x18\x96\xdd[l\xf5@Vy\xa4\xa9\xf8\x90\x01\xaa\xa5\xab\xfc\x9e\xe1\x8f\xec\xec@\x97\xbb\x82\r\xb0\x93\n.\x05\x03:\xb2\x08#(\xc3I(^\x89\xd4\x03\xb8\xf3)q\xc6v'
        b'\x903<\x00h\x13\x87*\xc3\xe1\xdf\xa3:\xf9\xe2:YQ\nCg~\xf2 \xdb\xd8\xc49\xc2_\xe5%\xf6\xf4nOh\x96\x19X\xaa\x14\\\xc4H\x9f\xa3\x18\xdf\xf0\xdbp\xfe\x83\xe3\xf6\xf9\x17}\x10\xd6$&\xdc'
        b'KP\xd0\xe3\xe9\xb0q\xe5\xde\xb3\xe3\x96\x80\xfb\xd8\xd7A\xb2\xed\x1dr\xc4C\xc5\xc9\xa9Y\xee\x7fzZ\x13\xc1\x15h\xe4\xa8\x8b\x14\xc1\x00\xab=x\xf6\xb4I\xaf\xb4\xebX\xd1\x8b,\xf8\x19^`\xa6\x10\x88\x14\xb4\x12'
        b'\xeb\x91\xaeqP\xc1H\x9a\xca\xb6\x9d?\xe7\xe9!{\xa2\x97\xe5\xa3\xb3x\x90`W\x08:\x96\x8aF{V]#D\xe3\xa1\x81MP\xdb"\x8c\x11i\x94m\x10\xab\x85\x06\xf3\xa0\x00,s\x0f\xb0A\x92\x9a-\xae\xbb'
        b"\x03\xa7\x89\xc7B)(\xed.\xd0'\xf3\xb9\x0c$\x95\xc7=\x05Pf'\xb2\x16\trmL9\xa47\xbb\xca\xf4\xa5\xbc\xbfy\xf7\xfe\xbd;Z\x19\x96t\xcf\xc3\xe7\x80\x83\xd8\xcd\xd3\x0b\x167g\x94h\t\x11\xa54"
        b'\x91YU\xa70i\x1b(T\xb6X$t\xe9\x1e\x02\x1cm\x9eK\n4\x92\xf0\x88iNQ8\x1fG\xdf\x7f\x98\x8eJ\xe8\xc7#G\x8dl\xa3P\x17\xa8\xd9\xab\x922\xd4\x94\x80{xr\xb4\x18W.\xec\x8a\xa1\x87'
        b'`\xec\x1eF\xd0\x9c2\xb7\xa7\xa4\xfa\xc6\xce\xa1Qr=\xf9\x06\xf9\xfa\x17\x80e\xdaV!(\xd0\x12\x12\x8dF.|u\x1d\xc6s\xf6\xda\x90\x18@\xc1\xb8Lf*\xcb6\xabk\xf3@\xe6\x16w\xb3F*m\xc4\x1f'
        b'\x8f\xf8PW\x8clm\x9f6A\xfc<q\xb5OV\x12\x14M\xde|\x83-G5 \r\x07?\xd5\x10\x88\xb8S\x8563g\xa9\xf6n\x94\r\x8bH\x1b\x1c\xd1Q\xb3tH\xd00\x00\x94\x1c\xd2|\xff\xa7\xd7rj'
        b'\xb3\xca\xba\x08C\x83\x01\x86\x9aF\x9b\x06\x8a\xeaJY!\x13V"\xdcow\xc2u\x14zLG\xe17x\xd3\x9c\xf0\x8a\xb2\xd1F\xaeT\xaa\xb5\xb4}\xc5\xa1\xe0\xe6v\xb7\xdf\xda\x0b\r\xfe\xb3\x10\xdb_\x04Q8\xaa'
        b'\xf4\xee\x9f&RX\xe6K\x98\xfdKz&\x00L\t\xa1ev1\xaex\xd0\xdc\xda[\xa8A\x83>\xce\x0fq\x89\xbf\x06\xd8s<\xdc\x17-T\xd0\xde"\xd5\xf7\x84m\xa7\xe1W\x08\x0cjCX\xa1\x85\x15\x0cZ\xbe'
        b'\xd4\x87\x7f\x13\x89\x06\t\xbb\xb4\x8e&\xa2\xd0\xc0\x97)\xd2\xf3\xf3\xae\x12X\x04\xb8\\\x80\xc9\xc0\xd8U\xe8\xb7!\xc3siW<\xba\xc5\xbd\xf64\x06\x0f0R\x8b\x155\xc1\xed\x9b\x95[b\x84\xdadlP7b\x8b'
        b'\x0e\x183\x85cCg\x1c4\xd2$\x1ez\x9df"\xdf\t;J\x10\xf65.\xe6\xa8yLE\xe9\xe8\x04\xe9\x9e\xd8"N\xfb\xa9\xf0\x81\xbf&;\x0f$R)\\u\xe7t5T\x0c\xfb.E7_+\xc6\xb3b'
        b'O\xbe\xfe|\xc4r\x85\xc1\x8c\xcf\xf3\x17\xd2\xbeZ\\\x8c<\xf5\x8f\xb4d\x0b\x01\xf3\x83%\xf9O\xcb\xfcBjf\xd7=\x00fiN\xb3\x05\xcb\xb6\x1f\x07\x11"Y\xe7\x04\xe3\x03\x1d\xea\xd7SW\x05\xbcb\xf292'
        b'\xc5\x1a,\x9b7\xc6.\x95\x91Qz*Q)\x19\x8d\x07$\xf1\xe4}{\x97\xe6\xc9\x02\xa5\xfa\xfbI\x99\xb5\xb1U\xc0\x97\x89\x0f\xc0p)1c:x\xdd\xba(o2\xa8b\x1e\x0f\xcd\xf6\xf8#<)\x10\xbfv\xb5'
        b'\xd7\x02\x00 `\xffs\x83\xac\x1a\x82\xaa\x96\xab8J\x11\x10\x9f\xf3\x0e\x8a\xf1\x8f\x90\x7fX\xe4\xce\xb4\x12\x82\xf4\xa04\x96\xd2\xc6-\xc3\xec\xaa+\xdf5\x9fQv\\B\x16~+\xdd9\x94\x1c\x05\x80GO\x07\x02\xdc'
        b'\x05\xd6\xabq4\xa1\xbc\xe5>\x85\x16\xe0\x18\x10\xa2\xe7\xe3^\xc4\xae4\xa2:\x02\xa6\x7fs\xee\xd6[E\xfc\xf6\\d\xdd\xbb\x18\xda \xd3I\xe5n\xf4+\xf4\x1e\x00\xe9\xe5#\x10\x8b\x15\x0f\xeb\x9f\x84\x98\x8d\xb6\xe3\x95'
        b'\xfdxY@\xd0\xbc\x8c\x0e\xb8B@\x01M\xe4p\xf9O#\xf2\xbb\x8bQ{\xeb)\x9d\x02\x94\x93Ni\x0fx6vR\x1f\xed\x8d"\x94l\x9a\x81\xe8^\x90\x8d\x9a\xf3\xc15\tr0"(5\x19p\xee"\xd9\xd6'
        b'\xd1?N\xa9\x11\x0f{\xd0\xedos8t\xca\x8e\xb6k_\xcc\x99\x80\xdd\x9d\xa3\xad\xc3O\xa6\xb6\xcfr\xf6\xdf\xcb[m\x12\xac#h_\x90\x11\xba\xd4\xf0\xad\xfc/\xcc\x0b\xe1\n\\\x1b\xe0\x98}N\xd7~\x06&I'
        b'\xaa\xdc\x19\x97\x95gC\x800\xd6\x91\xd5\xd3r\xf0\xdd?\\+\xd0v\xc7O*\xe0vZP\x1c\x1c\x0e\xc2\x9e\x84$u}\xd6[-Dw\xe9+\xbfG\xd8\xb7\xac\xde55(:\xf5r\xd0\xa1\xc3\x9c*\x81x\x80'
        b"\xeb\xb3\xf1\xd9{\xaf'\x98\x00\x93k\xe58\x80e\x00\xa2\xa6;-5\x96M\xaf7\xec\xdd\xd6\xd1\xd0+\x1a8\x91qY\xfdQK\xbf\xe3\x9frt0\xcd\xabY!\x96\xdd\x041Lvd\xd0\xb9\x12au\x99\x94\xb1"
        b"M\xa2\xe7gS[vg\x80u4\xf1' \x0c{]\xc3\xef$\xf8#\xb4\rE\x1f\x0c\xba\xce\x9fDy\x1fQ9\xebf\xe4j\x9a\xac\xe6\xfd\xb2\x18\xbd\xa0,LG\x01\xcc\xde\xa7`O\xd3\x9e\x1c4N\x17\xf0\xc6"
        b'\xf1\xa9\xd7Q\xcf\xa6V\xd4[\xd4\x8d\x9de\x04\xcb\x0f\xf7e3\xcfUo\xf4)|U\xe1m?\xed\xf5\r\xb7\xa3\xc1\xf3\x87\x94\xe9\xc7\xd5\xa1\xfd\xc8jv\xfd\x1b9>\x99\xdd\xfa\x04\xfd\xa7\x07\xc7\x99\x10\xd2\x06\xa4v'
        b'@\xfa\xaa<\xf5\xcf\xc0]\xac\xda\xed\xbd\x7fj\x94p\xb0A\x08i}>\xd0">\x02\x82-\xcd\x84+\xb8\x13\x0f\xf5R\xca\r\xb8k\xc9\x02]\x05+\xb3\xc8`J\xa0\xe6\xf5\x8ffA\x0eL\xbb\xdb\xea\xf6\xaa\xbb\x87'
        b'`3Db\xff;\xda\xc4\xa7\xdb\xfdo<3\xc3\xe9\x86kxK\xddw\x84u\xda\xd2Yn\xef\xfa\x90\xc6=c\xe4\xd2\xe3\x9bao\xc1\xb9\xbf\x04\xfa|/y\xd3\xacP\x13Vb\xed\xda\x96\x8d\xa0\xc5\xf4\x9e\xb4\xcd'
        b"\xf0\xcd\xdeu!4.E>w\xc8\xc42n\n\xca\xfc\x96\xb7\x11\xb3\xb1H\xa1\x10\x9d\xddME_\xb6F^\x82\xeb\x95W\xad'(\x88\xaem\xf5\x9a\xc3\x89\xde\t\xb6\xa7\x92w\xaf\xdef\xb8\x18\xbf\xfb;?F_"
        b'\xbe\x18\r\x18M\x0b\xe0\xa6\xb0\x0067Jm[\xe7\xb8B\xd5\xa0\x1d\x96\xc9.b\x07q[\xbc\xfc|\xbb\xb5\xa8\xd5R\x1f\xf6\x1f\xc3:\xa6\x8b\xe4\x9a\x13\xa9\xbcx\x1dV\xdb^\xcc\xb8\xdaR\x9e\x92Q\xb4Y}\x02'
        b'0\xf0\xab\xb3\xcf:\xd6\xdd\x9a0\xa4k\xf6\xba\x86X\x9d\x15\x87\x9a\x16^9\x8c\xb4\xbe\xd5\xf7\xb6\x8dV?Q\xd4\xa5\xfb\x9e\xbee,0\xe2h\x05\x85m\xca\x8e\x03\xf6\x1c\xbd\xd8 \x1e8\xb0\x93\xa2$\x8d+z\xbe'
        b'\x8a\x86\x07+"\x13\xcb\xe1;]\x03\x0b%0\x95\xde4\xc0\xf0$j\xf9\x98\x9a\xb9/\xc0\xf8\x8d\xe2z\xa3\x8e\xc5\xd2\x0c\x9c9\xd2\xce\xbc\xc9\xefh\xf7\x07J\xb0\x17d\xd0\x1a\xfb5\x7fH\xe1.\xd3\xca\x9c\x03Ps'
        b"*)\xfc\x17%\xfa\x9c\xf04@\xd5\xbc:\x16\xe9'\x87\xeba\xec\x0f\xb7\x90<\x98\xa2n\x98&\xda\x14d\xf3\xe6\xd9-:H\x1c\xc2\x9a\xcc\xf5uk\x90n\xfe\xfed\xd9\x1c\xdf\xf1\xd5\xc9\xfa8\x91&\xfd\x845\x8b"
        b'\xa9\x9d;s[\xb7\xe8K\xadWo\xddQ\x15\x00#\x0f\x18\x9d\xbeCw\\\x94\x13\x9a \xa8\xa4/\xf7\xe9\x91\xcc\xa34\xd5\x14\xad\x98\xaf\x07\xe1\xd1\x9d\xe9\x9et\xd5\x8e\xb8u\xcb\xc7\xc9\xffh{u\xccK3\x1c\xbb'
        b'x\x0fS\xfc\x80VN\x92D-\x0b\xae\xcd\xc2\xc3\xe3%\xbd\x19\x1aY\xe3|\xb1x\xb6\xa4j\xcd<\x1a\x88\xfb\r\xbb\x8f\\\x17\xe9\xef4\xf2\xbb@ \xd6\x9a\xc4\xb3+\x11\x19\x0c\xdft\x81\xef\x80\x9b\x1d?a\x7f;'
        b'\x9e\xd8\xa0\x81\x12\xc9\xe0\x1a\xe4\xf6\xf0+N2\x01\x9d\xb9\n"?z\xfdx\xa7/V>\x08\xc8\xaf:\xd2\x18\xa7\xeekO\x03\n/\x1c\x15I9\x0e\xf5\x0b\x10^U\x0c\xb9\xa2\x14\xf3r\x0e\x05\xfd\xec\xf1K\xfc\x19'
        b'@w\xfcU&4\n\xae\xe5a\xaf\x02\n$\x04\x82\x1cd\xfb(\x0by\xdcv/##\xfa\xe8\x94\xeb\xa7v\\\x93\xd8\xfd8\xa9\x1au\xce\xb02\x83\x07\x16>s\xcd\x06\xbcroO|e\xadP\xc0\xa0\xfa\x95\x18'
        b'\xcd\x10=\x02\x08\x0e\xa1\'\'\xef\xd4\xb9\x1e\x08\xb0\xcf0\x92\xa3\xa2$\xd0\xf0\xbb\x1e\xd4\x15!Zp\xff \x83\xd3d\xba\xd4\x9f\xef;\x1f\x8a\x98"F\xc8?\xba#(+\xe4\xa1\xc4\xd4\x03\xf2\x96\t\x96\r\x7f\x1a|'
        b'\x18Z\xea\x91?\xcd\t\xfb\x9d\xe6\xeb);\x13C\x8b\xad\x89\x13\xcf\x00\xfc<\xc4\xb2FPc\x14O1\xc30\xc0\x93\x01\xb4\xdf\x18v\xc6?\xfc\xf4<;\x92\xe2\xaf\x91W\xdb\x1e\x9b\xf99\xf4\xd2J\x15\xb3^\xf3\xf0'
        b'6\xbc\xa72\xeb\x04\x82\xea,\xa3\xf0\x87-\x9d\x18?\xea3\x80\x90\xbf\xd2\x8d\x06\xb0\xbfk\xa3\x0f\xa1N!%q#\x06\xa6\x8f#k\x06z2D\xe8\x8d\xe4\x7f\xe8R+u\xd0\x10#l\xf2\xd3Y=kaU\x17'
        b'H\xe7`\x9bR\xab\xef0\xee\xddQt\xbb\xc4\x8ei\xec\tP\xc7\xcdc\xf0#\xac\x15Uw=N\x84\xdf\x0fu\xc8k\xa9D\x96U\xd5%\xac\xdb\x00s\xc3S*\xdd!X\xdaT\xd53\x95\xb7\xf9\xa0\xf1I\xba\xb7'
        b'\xde\x9e<\x0b\x98;\xde\x19\xd3\x05\xd4\x85\xfb\xa8h\xf4w\xf3\x03\x1d\xa1vq\x04\x18\x91R\x11\xe9>/v\xe30/\xd9\xce\xd9.}\xb5\xceq\xaf\xaa\xe6\xd0\xf0C+\xe4\xc8\xd1\x10#*\xe5~G\xa7"C\x1e\xf2'
        b'H\x8f\t\x1c\x00\xdc\xee\x95\x0f\xafl\xa9\xbd\xfc\x0bsL\xc3\xd5S\xc0\xcd\x8b\x8f\x80\x0f\xb9uvHIDm\xf2\x9f\xe8\x06F\xcb^\xb0\xda\xe3\xb0W\x00\x17\xd3\x87\xc4\xa0\xea \x98\x97\x87\xc5\\I`\xd5s\x9f\xec'
        b"8c]\xa1\xa6\x01\xb8)\xc1\x81aVWpD\x1d-\r\xb2MM\xe8s\xd8Yk\xa9\x10\x9917\x95\xbe'\\\xa8\x1cS\x9a\xf2#\xbb\xba\xce\xf2\x91;s\xa7\xbef\x04\xb7-\xa9r\xf0\xa0\xe5\xea\xeb\x9d\x87#"
        b"R^&\xa8\xad\x06\xbd\r-5\x989\x94\x83<U\x0c\xd4e\xa7\x8a\xe7n\xb6\xd1\x12\x89\xfd\x82\xd0\xcc@'\x1a\x8d<\xecgU\x04\xbd\x02oZb\xaeukU\xd51\xe9$!\xa0\xdd\x9d+E(\xda\\\x9e\xd7"
        b'\x1f\x9e\xa9\x844\x00\x11\x90\x06\x08\x18\x1c\xf7@\xdf\x9ct\xd3\xe8\x11 \x9eCs$@\x96\xa0\xad\\\x91\xf7\xaa\x19\x9e\x0b+_\xe1qd\x0c\x02\xaf5\x87N(>\xc2\xa6\xa0z\x17\xf0)8S\xa4\xa5\x0f\x844\xc4'
        b"\x18\x16S#\xef9\xfe\xd2~\xca\xfc\x1f'`>\n\xfa\xf9\xd4r\xadF\xc1\x1c\xcau\xfd-\xa4D:\x90\xd0\xeen_\xba\x81\xc3P@N\xf2Sw\x19\xf8\x19r4\n2\x90\x8f1&\x9f\x9d.\xc7-\xcc\xe4\xb6"
        b",\x1b\x8aLU\t\x94\xcd\rB\xb6G\xaf\x83\xc1B\xdf\x99\xe558\x00\x92\xaa%\xc7)W\xc7\xcb\x10J)'\xe3Y\xfc\xdd\xed\x8e\xc2G\xda\xe5\xe4v\xe6q\x8e\xfa\xe4\xcd\x1c\x02\xa8\x9f\xb0\xa5\xda1!\xb5\xc8p"
        b'B\r)o\x87g\xbe\x86=N\xc6tP_\x9bht?+\xaf\xeeF\xdd\x9a\xaa\xac\xb6\x81\xd5\\\xf98\x15\xc0\xa0chNA\xc6\xfc,<`\x93oy\xe2jZi\x85Y\xcaw\x18@q\x1c&\xfaz\xa5\xd4'
        b'\xfe5{e\x9d}\xd4g/\x9dr\xbc\xba\xb8y\xde\x8b\xf1{\xd5\xc1?\xda\x19\x92\xafg>\xb7[\x8e\xbcl\xa8-\xa8\x12\xb4\xc2\xbecj\x164/\xc9\xedaB\xa7U !\xfd\x97\xae\xae\xa9\r\x07?\xfd\x0e\x8a'
        b'\xeb\x17\x08\xc7U\xa0\x1e(U\x95\x91;\xf2T\x02\xdf\xed\xf00v\xcd\x1e\xb9}L\x10\xee\x8e\xc9TTQ\xb2\xf9J\xeb-m\xfa\xb8\xc8o\xf6z\xa6\x97\xbd\xc3(\x9f\xf2\xe5X\x84\xa1`\xac\x19\xe6gY\xac\xdcP'
        b'f\xbeN\xac  \xfe\xd7B\xed\xee\xcd\xa0}\xf9D\x97\xcd\x81m\x9d\x94\xf4S\x8b\xb4\xb3\x9d\xe5\xd5X\xa8\x8e<{s\xe0\xe6\x90\x85\xc0\x8c\x93$\xeeG\xe15\x19EZW\xc1ZWVx\x01\xe9\x8b\x04\xe7\x90\x19'
        b"\xb3u\xc7\xcf\xaa\xf793G\x86+\x1b\xe3\xde\xb6{\xaa\x9c\xec\xc4k\x11'QK\xb2\x1ea~6\xb4M>\xc5\x11sf\x94\xe3@\x03z\xcc\xd4\x13\x0c\x91J\xb9\xbd\x91\xb5\x1a\xc0\t\xb3]8\x03\xcbQV@Y"
        b'C\x87i\xe7-\xa9\x1dy!\xb4\xd0u\xcc\x90#B\xe6\x86O\xd1@*\xb6\xe2\x1c\xb6\xcd\xec\xe3D\xb5\xf5\xc9\x98\x9b\xd9\x18\xdb\xa5\xc5;\x88V\x9f`\xee\x03V\x9f\x02\xc7u\\z\xe1c\x90\x14#\xd1\xe1\x9c:@'
        b"\x9ej=\xb9\x9f/\x9f\x81\xea@\xear\x0eo\xd5\xf5\xbb\xe5\xf1\xc8\x08a|\xb7\xfcxCXs@J\x0c9kU\xe0',\xda\xcave\x0eP\xe5\xdcw\xe5#*\x12\xc4\xfd nz\x02\x8b\xcb\xb6\xd9\xd3\x90\x94"
        b'e\xc20\xd3\xea\xa7\xfe}\x93\x1f\xd1\xd7\x92\xe5\x1d\xb0\xf1\x8e\x8fnH\x86\x17\x12\xc2`\t\xcfW\x9c\xcf\xd5\xaf\xf2\x90m\xc0\x07\xf1\x08w\xeb\xbcO\xf9\x80\x01~\xdfLO<>c7s\xc8\xde!;\xe2 S\x12'
        b'\x8e\x9a${\xe4\xcfb\xae\xf7H\x84\x99Q\xe4`Vc\xa2\xc6\xfd\x7f"[\x18v\x94L\x13\x0e8\xb7\xe6m\xec\xa6\x9f\x0e\\\xb0D[\x83\x7f7\xea\xa28\x16\xd5&\x16h\xe7\xd3\xb0\xe4\xf6y\xbe\x81\xd9\x8e\xb4,'
        b'\xed\x08D@\x1fV\x80\xb4\xdd\xae%\x90\xe6\x07g\\\x1c\t\x97B\x1b\xbf\xa3\x9f7P\xf2%\x173\x07\xc6\xa1\xa8\xde\x82\xac&\xb8\x04\xa9\xf7(\xf8\x81\xde\xe2\xf56k\xdd\r\xe6@\xd6\xe2W\xe3\xa8i\xbeo\x83\x98'
        b'\xa51|`]\xfatK\x0fJso\xc5\x1b_@0\x08O\xec\xd9\xf1`v\xf4\xb7Qm\xb2L\xd7z\xc0\x8c\xd8\xdf\x1eM\x8c\xe3\xeaZ\x1c\xc6\xda\xae\xbdJ\xda\xe9\x8c;\x01\xde+5Z\x9d%n\xc7\xc7=S'
        b'h<\xb1\xd3zmZ\xf54\x84\xe8V\x95\xee&\xfb"@\xa0\x08j\xfdZ\x8e\x95\xa2\xa1y\xfc\x89\xce\xd2\x9e{\xe9\xee\x0e8\xb1\n\xd5>\x91<1[y\xe6\xb4\xadSE\xb5Su\x00\x1a\xeb\xbd\x88\x87\xfe\xa9\x1d'
        b"\xd9\x81\x10h\xc7\xc4\xab\x9a\x81y\xed*Qtp\x96\xb4m\xda\xa2$\x1f\xb4\xd3\x07^S\xc3\xf4\xf3\xe3=\xe5\xe1\t\xfa\xf2\xe4\x86\xe8\x83\xc7!'i\x89'\xd2x\xee\xe2\xb8<a\xebj\xe2S\x08\x00m`$\xc8"
        b'\xdf\x06\xa2*9\x95\x9bD\xc1c\xde\x91m^rP\x93(\x13k\xeb\x1e\x14\x84\xf35\xad\x9b\xb4\xd1(\x7fX\x1b \xf5\xbbN\x96\x94\xf2\x19\xf65"\x0b\xdd#\x8b\xebT\xae\xe1Mo\xba\xd6\xa2\xd0\x96\xf8\xa2\xefV'
        b'<,\xfc\x93\xbf\xe1Bh\x95\xd8gJn\xa7\xa4\xf0\x9b\xbf\xe8TU\xc6\x8cN#N\x81\x1b\xf1^\xa2\x12e\xd5\x98\tENy\xb1\x99T#\xf5rif\xcd\x1bRy\x1d[\x1d\x86\x91\x17N=\x0f\x8f3l\x0c'
        b"5\x17\x89\xd84\x13R\xb3\x12\xe2\x12@\xac'\xbc6\x8e-\xc9=G\xea%\x85\n=\x80\x8f\xf3\xa0\x8f\xe2\xfa\xd0\xcbe\x9d;\t$\xd9\xd5\xbe\x19\xb9\n\xb8\x87N\xf6\xb5\x8d\x1e\xbdQP\x05\xc9\xdc}\xf43\xc7\xf8"
        b"\xf1\x8b\xb1\x8fx}\xbfU4\xde\x8f\xe9t\xf9\x89\xbd'D\xeb\xf0\xbe\xfb<\xc3\\\x18#\xca;\x1cU\xa3\x81K\xa9\r\xcf\xae\x1a\x9b\xec.\xac\x0e\x1a(z\x95\xf6\x1aV\xcf\xf3\xf1\xdb1\x94\x0e\x9b*\xb7{\x9c\x07"
        b'\xa8\xcf\xf2\x16\xb1}\x93N\x8e\xbeb\xaa\xad\x931M\x83\xcb\xcf\xe4Y\x01\xe0\xa4\x1b\xc5\xdf\xaa\x15+d\xbc\xe5\r*\xcb\xec\xf9u\x1e1\x8fWU\x98\xf7\xad\xe3/\x03\xb3#yVm\xacY\xc7j\xee\xea\xb0o\xfb'
        b'\xfd=\xfbf|\x1f\x1cw5\xb8\x9c4\x97\x0e_\xb8\xa8Q\x9c\xc1]\xf5|\xc1\xad\xf0\xee\xd0\xady\x92\x05\x95\xde\x96t\xecR\x15\xaay\x8c\xfa\xa1#Ie1S\xf1\x18an\xcd\xce\x89\x83YV\xe9\x0b\xf2N>'
        b'\x99#.\xcb\xa5\xc1\x01\xaf\xf3\xebC\xc7\x9a\x02\xec\xaf\x8ft\x06*y\xb8\xbda\xed\xa9++\xc6Oy\x90W\x1c\xf4\x87\xfb_\x10\xf0\x8ad\x17\x9b\x19\x0e\xfd\x1f\x91V\xb5\xb5\x91(\xb4I\xf9\xcfH\xd3\rN%\xc7'
        b'$\xc7gC\xc5\xe8\xd4\x8f\xde\xf9\xca\x92\x84\x15\x93\x99\x94\xf9\x94\x8c\xee\xe5\xea\xd7Z-\xc3\xc6<xOF\xaf\x17;S\xa8\x9cB\x96\xb2\x19~\xd2t\xdc\xf1!o-\xc1%\xb9$\x19\xcf\nJ\xf8\xf7``\xea\xcd'
        b'\x07\x10"\x07\xf1\\:m\x8d\xf0\x85{\x8c8\xfc\xa8\xb890\x89\x86\xb6D\x19x\xfb\x1btG\x82\xe6\xf6l\x18::1X\xb5;\x10,%\xec\xfd\x11]\xc7\'\x041C\x95\xe0,!k\xa2A3\xf6\xb3\xe12'
        b"N\xe6_\x17\xd3\x10\xa4\xc4\xa1\x02\x99\x02p'\xd36\xf5\xa7\x93\x1e:\xf8F>.\x1be[%\xd6\xa21\xe0,\x00=\xac?\xfc\xa6\xccbl\xfbPAdu=\xef\xc5\x92\xb7\x06SL\xd8Z\xde\xaf\x93\xf3\x00\x9a"
        b'\xc8\xce2\xc3\xbe1\x80\x9b\xa2Z\xb2U\x7f\x0c\xcb\x0f[\xf1z\xe2\xd7\xe2\x1e^jv\xcb;(\x19+`f\x88r\x91v\x86\xc6\x8d\xbfzJ\xe4>p\xa3\xda\x8d)\x86\xcfw\xaf\x92\xe9\xde\xb0J\xb6\xdc\xaa\xd1s'
        b'\xc5)\xbf\x99v\xc8j[\xad\xa9\xe5\xc7\'\x16L_\xf5b(\xcf\xd0cwR\xc6\x0b\xf8\t\x9a\x18\x11\xbd\xe6\xaa\xd3\xd4*\x88\xec\xbcQ\xbc\x99#\xbd\xec\'\x11\x12\xaf\xcb\x82t\\"\xf7{2D:\x1e?q\x99'
        b'\x8e\xe2\xd6\xe0\xfd\xa9\xfda\xa2\x10\x90\x1b\xfc%\x9aX\xb13WW\xfb\x8f\xc54\xf78\xef\x98\xa7\xbb\xb8w\x90d\xdc9.\xd5\xb4\xf8k\xe1\x8e6\x9fJl\xabQ^L%\xaf\x97$\xbc\xce\xc5M\xfd\x9d#\xf0I'
        b'ph1\xe0\xbe?SI\xf0\xd7\xef\xf1\x87\x06\x12H\xad\x12Q\x05\x98$\xdc\xc1hA\x16\xa6\xb9}n\x98\xc3\xb0\xcf#\x86\x0fD\xa9\x82\x10\x9b:\x1bt\x83\xbe\x8eO\xad;o\x80\xb9{\xe8r\xcb\xd9R#\xa7_'
        b'..>[\x9c\x90\x84=\x1e\x83j\xdcg\xd2`\xc3#\xedM\xb0\xfdC\xba\xc5\xac\x91d5n{Tx\x10\xafo\x9ce_\xf0\x01\xdd\x8d\x14\xaf@\xed\xb2r\x0e\x8e1^|\xd8\xebBYt\x98F\xdf}t\xde'
        b'\xc8\xe1\xd7\xb3\x81\x97\x10N{Y\xab\x9c\xb5.F9l\xf2\xf2\xae/\x83\x99\xb9\x1c\xa8\x02\x00N\xf94\xa3\x87\xe3v|\x9f3U\x00P\xe4B]\x08g\x9fN@\xe8-\xf5\x9e[\xa7\xee\xcc\x9d\xd2\x02|\x1e\xd7Q'
        b'\xbei\x82Pd\x81\x97\x1a\xda8\xf1`A\xb3\x9b\xf3p.\x95LV$7N&\xda\x01y1\xcey~\xed\xbenv\xcfh\xfa\xab\x86\xc18\x9b\xf0\x88\xa5Fw\x8b\x81\x15\xd3\x9e\xa1\x02s\xc3\xf3\xb55\xa0\xa0^'
        b'(`\xf5\xf8\xec\x0ep\xc0\xdf\x1b)\xd0[\x9f\xff\xf1\x92Q\xd8 s#PuG\xf2\xe4\x03b!\xc4\xbc\xc6\x1c\x1alZs\xd7\xcd\x92g\x8b\xc5\xd8\x06\xdfi\x04#q\xf4\xa3S\xb9\xd4}\xeb\nnU<\xb0o'
        b"\xb7\x91\xe9\xcaX3\xaa\xcc\xf8\x08'\xee\xdc\xbc`\xf1bq\x97c\xa0I\xbfo\x89\x0b\x98:\x7f\xff\xc50\x08|\xf9R\xf0\xe3\xb6\xf6KD\x99\xf1)\x04Q\x1e\xf1\x12\xf5\x041\x03\xe6\xcd\x81\xdeEV\xed3\xc9\x95"
        b'S\xb7\x05\xb2\xedHhJ\x1b3\x02\xc3\x9ddg\x06\xc8\x15\x05uX\xd0\xfcn\n\xee\x13\xb6\xd27r0\xfe\xb9\xfc\xc7h\xd8\x86B\xac\xa5W\x03\xc44\x92\xddh8\xb9|t?\xc3a\x14U\xe6<\x9e\x9a\xd3\x01'
        b'\x9d\x86\xc1\xc1\xd5\x12\x12\xcf\x086#[N)\x04\xda\x07runtimer\x03\x00\x00\x00\xda\x08__name__\xda\x08__file__\xa9\x00\xf3\x00\x00\x00\x00\xfa\x16<froze'
        b'n fintech.swift>\xfa\x08<module>r\n\x00\x00\x00\x01\x00\x00\x00sJ\x00\x00\x00\xf0\x03\x01\x01\x01\xe0\x00 \xd0\x00 \xd0\x00 \xd0\x00 \xd0\x00 \xd0\x00 \xd8'
        b'\x00\x0b\x80\x0b\x88H\x90h\xf0\x00\x00!d\\\x10\xf1\x00\x00\x01e\\\x10\xf4\x00\x00\x01e\\\x10\xf0\x00\x00\x01e\\\x10\xf0\x00\x00\x01e\\\x10\xf0\x00\x00\x01e\\\x10r\x08\x00\x00\x00'
    ))
